package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M?T5,1@$"`0,````````````"``\````!``$;U````#0``-KP```"$``T`"``
M!P`H`!P`&P````8````T``$`-``!`#0```#@````X`````4````$`````P``
M`10``0$4``$!%`````T````-````!`````$````!```````!`````0````#3
MX```T^`````%```0``````$``-/@``'CX``!X^````0$```43`````<``!``
M`````@``T_0``>/T``'C]````/````#P````!@````0````$```!)``!`20`
M`0$D````(````"`````$````!&1TY5```-.8``'3F``!TY@````4````%```
M``0````$+VQI8B]L9"YS;RXQ``````````0````0`````4=.50``````````
M`@````8````/````80```',````2``````````````!?`````````&H```!I
M``````````````!4````6@```%````!"````2````#0`````````2@```&\`
M```#````.0```&,````;````1@```$0``````````````%(```!8````.P``
M````````````&````&4```!.````$0````````!N````<````$4```!R````
M`````&(`````````8`````````!A````50`````````C````"@```%,`````
M````,0``````````````0P```!`````X````:```````````````3```````
M``!;```````````````W`````````%T````N````$P```$````!M````!P``
M````````````"````"P```!6````,````'$````H````30`````````5````
M```````````Z````1P```%P`````````9````!H```!>````9P```&P```!!
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````&````#0``
M````````````````````````````%P`````````````````````````,````
M``````X````````````````````9````````````````````%``````````$
M````)@```"(``````````@```"\````?````````````````````````````
M```S```````````````R````-@````D``````````0````\`````````````
M``4````=`````````````````````````````````````````"$````^````
M+0```#\````6````)0``````````````'````"`````G`````````%$````U
M`````````"L```!+```````````````I````60``````````````````````
M```]````'@```%<````J````20````````!F````/````"0`````````````
M`$\```!K````"P````````````````````````4@``'DY``````@```5```$
MZP``````````$@``````!&4``27`````*!(```L```1V``$HX````(02```+
M````)P``````````$@```````#X``````````!(```````0B``'GZ`````0A
M```8```$@P`!<Q@````$$@``"P```]<``````````!(```````4D``$;U```
M`%`2```+````2```````````$@```````UT``````````!(```````!3````
M```````2```````"_```````````$@```````ZT``````````!(```````!F
M``%UO`````0B```+````=0``````````(````````(D``````````!(`````
M``0J```````````2```````"&```````````$@```````)T``````````!(`
M``````"O```````````2```````$C0`!=<``````$@``#```!),``69D```&
M^!(```L```,V```````````2```````$J0`!+5P```"<$@``"P``!+<``22(
M```!.!(```L```0A``'GZ`````0A```8```"[0``````````$@```````[0`
M`````````!(```````"\```````````2```````#F```````````$@``````
M`,4``````````!(```````#3```````````2````````$0`!Y\0`````$0#_
M\0``!,T``2ED```"`!(```L```39``%53````%@2```+````XP``````````
M$@``````!/0``6((````E!(```L```/X```````````2```````#50``````
M````$@``````!0```>3\````!!$``!4```#Q```````````2```````%;0`!
M>6@``%==$0``#0``!0\``77X````!!$```T```#\```````````2```````#
MW@``````````$@``````!"```>?H````!!$``!@```$0```````````2````
M```$-```````````$@```````X,``````````!(```````4>``'DY``````0
M```5```!'@``````````$@```````3```````````!(```````/)````````
M```2```````#>P``````````$@```````3X``````````!(```````4K``'D
MY``````1```5```#D0``````````$@```````4X``````````!(```````0'
M```````````2```````!7P``````````$@```````7```````````!(`````
M``/N```````````2```````#%@``````````$@```````T@``````````!(`
M``````4T``$=(````'02```+```!?P``````````$@```````TT`````````
M`!(```````-U```````````2```````%/``!<QP```"H$@``"P```XH`````
M`````!(```````&.```````````2```````!G```````````$@``````!%0`
M`>?D`````!``__$```-F```````````2```````!J@``````````$@``````
M`Z8``````````!(```````&V```````````2```````!QP``````````$@``
M````!`X``````````!(```````-N```````````2```````#YP``````````
M$@```````P(``````````!(```````5,``%EU````)`2```+```!V0``````
M````$@```````>X``````````!(```````1@``'X+``````0`/_Q```#)P``
M````````$@```````@P``````````!(```````(?```````````2```````%
M:``!Y/@````$$0``%0```$,``````````!(```````+U```````````2````
M```"+```````````$@```````CX``>?P````$Q$``!@```5W``%8+```"$02
M```+```$````````````$@``````!$T``>?D`````!``__$```)-````````
M```2```````%A``!5J0```&($@``"P``!98``27H```"^!(```L```/!````
M```````2```````"6```````````$@```````F<``````````!(```````)Y
M```````````2```````"C@``````````$@```````[H``````````!(`````
M``.?```````````2```````%HP`!*V0```'X$@``"P``!!L``6X````$\!(`
M``L```4V``$6_``````2```*```"GP``````````$@```````K8`````````
M`!(`````;&EB<&5R;"YS;RXU+C$P`%]'3$]"04Q?3T9&4T547U1!0DQ%7P!0
M97)L7TEC=7)S=&%C:VEN9F]?<'1R`'!E<FQ?9G)E90!P97)L7W!A<G-E`%!E
M<FQ?871F;W)K7W5N;&]C:P!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#
M;&%S<V5S`%!E<FQ?265V86Q?<F]O=%]P='(`4&5R;%]):6Y?979A;%]P='(`
M4&5R;%]);W!?<'1R`'!E<FQ?<G5N`%!E<FQ?879?<VAI9G0`4&5R;%]G=E]F
M971C:'!V`%!E<FQ?<W9?<V5T<'8`<&5R;%]A;&QO8P!097)L7T=D;U]U;F1U
M;7!?<'1R`%!E<FQ?9&]U;G=I;F0`4&5R;%])=&%I;G1E9%]P='(`4&5R;%]S
M>7-?=&5R;0!B;V]T7T1Y;F%,;V%D97(`4&5R;%]A=&9O<FM?;&]C:P!097)L
M7VYE=UA37V9L86=S`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?<W9?<V5T<'9N`%!E
M<FQ?879?9F5T8V@`<&5R;%]D97-T<G5C=`!097)L7VUG7W-E=`!097)L7TEP
M87)S97)?<'1R`%!E<FQ?27-T871B=69?<'1R`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!097)L7VYE=U-6<'8`4&5R;%])=&]P7V5N=E]P='(`4$Q?;65M
M;W)Y7W=R87``4&5R;%]N97=84P!097)L7W-Y<U]I;FET,P!097)L7T=T:')?
M:V5Y7W!T<@!097)L7TEE>&ET7V9L86=S7W!T<@!097)L7TEC;VUP8W9?<'1R
M`%!E<FQ?<V%V95]D97-T<G5C=&]R7W@`4&5R;%]S=E\R<'9?9FQA9W,`;&EB
M9&PN<V\N,@!L:6)M+G-O+C8`;&EB<'1H<F5A9"YS;RXP`&QS965K-C0`;W!E
M;C8T`&-L;W-E`'!T:')E861?9V5T<W!E8VEF:6,`7U]E<G)N;U]L;V-A=&EO
M;@!R96%D`&QI8F,N<V\N-@!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-P<FEN
M=&8`<W1R;F-M<`!C;&]S961I<@!S=')N8W!Y`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&UE;6-H<@!G971P:60`<W1R9'5P`'-T<G1O:P!S=')L96X`;65M<V5T
M`'-T<G-T<@!R;61I<@!M96UC<'D`;W!E;F1I<@!?7V-T>7!E7V)?;&]C`&=E
M='5I9`!R96%D;&EN:P!E>&5C=G``<F5A9&1I<C8T`&UE;6UO=F4`86-C97-S
M`'-T<F-M<`!?7VQI8F-?<W1A<G1?;6%I;@!?7V5N=FER;VX`7U]X<W1A=#8T
M`%]?;'AS=&%T-C0`;&EB8W)Y<'0N<V\N,0!?961A=&$`7U]B<W-?<W1A<G0`
M7V5N9`!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M90!?7VQI8F-?8W-U
M7V9I;FD`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`<&%R
M7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`&=E=%]U<V5R;F%M95]F
M<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'-I>F5?;&]A9%]M95\R`%])3U]S
M=&1I;E]U<V5D`%]?9&%T85]S=&%R=``D9VQO8F%L)`!X<U]I;FET`%]?;&EB
M8U]C<W5?:6YI=`!84U]);G1E<FYA;'-?4$%27T-,14%24U1!0TL`;F%M95]L
M;V%D7VUE7S(`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F
M:6YD<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?,BXR`$=,24)#7S(N,P!'3$E"
M0U\R+C,N,@`````!``(``0`!```````"``$``@`!`````@````,``@`!````
M```"``(```````$``0`$``$``0`"``,``@````(```````$``0`!`````0`"
M``(``0````$``0````(``@````(``@`!```````%``(````!``(````"````
M```"``,``@`!`````@`"``$``@```````0`"`````@```````@`"``(``P`!
M```````!``,```````$``@`#```````!``(``0````$``0`"````````````
M`@`"``$``0`!``````````$``0```MT````0````(`UI:1(````#```%L```
M`````0`#```#+````!``````#6EI$P````4```6Z````$`EI&7(````$```%
MQ````!`-:6D2`````@``!;````````'GU```(P$```````'GZ```,(``````
M``'G\```8(````````'E$````H$```````'E&```!8$```````'E(```!H$`
M``````'E*```"($```````'E,```"8$```````'E.```"X$```````'E0```
M#($```````'E2```#8$```````'E4```#H$```````'E6```#X$```````'E
M8```$($```````'E:```$8$```````'E<```$H$```````'E>```$X$`````
M``'E@```%($```````'EB```%8$```````'ED```%H$```````'EF```&($`
M``````'EH```&8$```````'EJ```'8$```````'EL```'H$```````'EN```
M'X$```````'EP```(($```````'ER```(8$```````'ET```(H$```````'E
MV```)H$```````'EX```*($```````'EZ```*8$```````'E\```*X$`````
M``'E^```+H$```````'F````+X$```````'F"```,8$```````'F$```,H$`
M``````'F&```,X$```````'F(```-8$```````'F*```-H$```````'F,```
M-X$```````'F.```.($```````'F0```.8$```````'F2```.X$```````'F
M4```/($```````'F6```/8$```````'F8```/H$```````'F:```/X$`````
M``'F<```0($```````'F>```08$```````'F@```0H$```````'FB```1($`
M``````'FD```18$```````'FF```1H$```````'FH```1X$```````'FJ```
M2($```````'FL```28$```````'FN```2H$```````'FP```3($```````'F
MR```38$```````'FT```3H$```````'FV```3X$```````'FX```4($`````
M``'FZ```48$```````'F\```4H$```````'F^```4X$```````'G````5($`
M``````'G"```5H$```````'G$```5X$```````'G&```68$```````'G(```
M6H$```````'G*```6X$```````'G,```78$```````'G.```7H$```````'G
M0```7X$```````'G2```8H$```````'G4```9($```````'G6```9X$`````
M``'G8```:($```````'G:```:8$```````'G<```:H$```````'G>```:X$`
M``````'G@```;($```````'GB```;8$```````'GD```;X$```````'GF```
M<8$```````'GH```<H$`````*V```$@U`/CJH,``2#,!`&O"/]EOQ`"`:],_
MP>A?'[T($P)$"`0"4^A`"V@(``)`Z$(<'`@``D!+PC]9"`0"4^A`P`!/Q#^!
M*V```$@U`]CJH,``2#,#X"M@``!(-03HZJ#``$@S!/`K8```2#4#:.J@P`!(
M,P-P*V```$@U!#CJH,``2#,$0"M@``!(-0!HZJ#``$@S`'`K8```2#4"&.J@
MP`!(,P(@*V```$@U!(CJH,``2#,$D"M@``!(-0((ZJ#``$@S`A`K8```2#4$
M>.J@P`!(,P2`*V```$@U!`CJH,``2#,$$"M@``!(-0!8ZJ#``$@S`&`K8```
M2#4"6.J@P`!(,P)@*V```$@U!%CJH,``2#,$8"M@``!(-03(ZJ#``$@S!-`K
M8```2#4`J.J@P`!(,P"P*V```$@U`[CJH,``2#,#P"M@``!(-0+(ZJ#``$@S
M`M`K8```2#4!R.J@P`!(,P'0*V```$@U`>CJH,``2#,!\"M@``!(-0"XZJ#`
M`$@S`,`K8```2#4#B.J@P`!(,P.0*V```$@U`7CJH,``2#,!@"M@``!(-05H
MZJ#``$@S!7`K8```2#4"Z.J@P`!(,P+P*V```$@U!)CJH,``2#,$H"M@``!(
M-05(ZJ#``$@S!5`K8```2#4#&.J@P`!(,P,@*V```$@U!-CJH,``2#,$X"M@
M``!(-0'8ZJ#``$@S`>`K8```2#4"*.J@P`!(,P(P*V```$@U`GCJH,``2#,"
M@"M@``!(-0,XZJ#``$@S`T`K8```2#4#6.J@P`!(,P-@*V```$@U!/CJH,``
M2#,%`"M@``!(-0!XZJ#``$@S`(`K8```2#4"F.J@P`!(,P*@*V```$@U`.CJ
MH,``2#,`\"M@``!(-00HZJ#``$@S!#`K8```2#4#^.J@P`!(,P0`*V```$@U
M`?CJH,``2#,"`"M@``!(-0*HZJ#``$@S`K`K8```2#4#J.J@P`!(,P.P*V``
M`$@U`YCJH,``2#,#H"M@``!(-02XZJ#``$@S!,`K8```2#4%>.J@P`!(,P6`
M*V```$@U!0CJH,``2#,%$"M@``!(-0$XZJ#``$@S`4`K8```2#4#2.J@P`!(
M,P-0*V```$@U!&CJH,``2#,$<"M@``!(-02HZJ#``$@S!+`K8```2#4!*.J@
MP`!(,P$P*V```$@U`;CJH,``2#,!P"M@``!(-0)(ZJ#``$@S`E`K8```2#4#
MZ.J@P`!(,P/P*V```$@U`CCJH,``2#,"0"M@``!(-0&8ZJ#``$@S`:`K8```
M2#4!&.J@P`!(,P$@*V```$@U!3CJH,``2#,%0"M@``!(-04HZJ#``$@S!3`K
M8```2#4%&.J@P`!(,P4@*V```$@U`HCJH,``2#,"D"M@``!(-01(ZJ#``$@S
M!%`K8```2#4#".J@P`!(,P,0*V```$@U`:CJH,``2#,!L"M@``!(-0+XZJ#`
M`$@S`P`K8```2#4!6.J@P`!(,P%@*V```$@U`-CJH,``2#,`X"M@``!(-0,H
MZJ#``$@S`S`K8```2#4!B.J@P`!(,P&0*V```$@U`FCJH,``2#,"<"M@``!(
M-008ZJ#``$@S!"`K8```2#4!2.J@P`!(,P%0*V```$@U`)CJH,``2#,`H"M@
M``!(-0/(ZJ#``$@S`]`/P!*9:\(_V3?>`(`/WA*9:],_P6O7/Y$C2R``2UH+
MT"+K(`!*]POH(LL@`$K6"^!KUC^9:]X_B2-O```W>PG(Z%\750@``D`$````
M"``"0```5_!KPC_9*V```$`\!D!OQ@"`"`$"1FO%/XEKQ#^1CX`@L&O#/YDK
M8```"`$"4T@\!D@K?___-"4.""M___\T(0X0"*$$`=`A'Z(T(S__@X.@0#9D
M!D@WG``"#)P2@`R\();KX@[L"!\"0@R`$)R+@[_--YP``C0<``)@W`9`2\(_
M64O%/XE+Q#^12\,_F>A`P`!/QC^!:\(_V3?>`(!+PC]9Z$#``#?>/X%KPC_9
M*W___S?>`(!(/`X8AX`@,#0Z#A@CBR``2Y8+^(;`(!A+PC]9Z^(.#`@?`D)+
MPC]9Z$#``#?>/X%KPC_9-]X`@$O"/UGH0,``-]X_@6O"/]D(`P)!"!X"0V_!
M`(`CBR``-YP,``Q\$I`T&@``Z%\9?0@``D`/@!"<"!P"6NA?%!T(``)`"!P"
M4R.+(``WG`Q0#X`0E`@3`EHCBR``-YD,&`@4`E@,<!"7Z%\6Q0@``D!(8C_9
M-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$@@&AY/[%H>#^I-',`&".+(``W
MF@Q8"!,"6308'_[H7QF="``"0`Q\$I`,<!"<CX!`2@QP$)PWDS__-'P`&`I\
M"AP/@!`<TYP?^(^`(!(,<!"<-YP__PQ\$I`,<!"<CX!`N@QP$),T?``8"!P"
M6C09`%X($P)8Z%\:S0@``D"'@"!Z-!H``.A?%ZT(``)`#X`0G`@<`EKH7Q)-
M"``"0`QP$)0T<P`8"!P"6DAY/[$($P)8"!0"5^A?%XT(``)`Z```6C0:``#H
M7Q<M"``"0`^`$)P('`):Z%\1S0@``D`('`):2'D_L4AX/ZGH7Q.%"``"0$AB
M/]DT?@"`3\,_@>A`P`)KPC_9"`,"00@>`D-OP0$`:'H_N6AY/[%(<S^YAF`@
M&BM@```T/`8(#X`0G(^`(`IH8``PZ``!^DA\/[EH?``@Z```$DAS`"`V<P`"
M:',`($AS`"`.8!`<TYP?^(>`("I(<P`@#F`0'-.3'_@T'`!ZBGP_G0@``D!(
M<P`@2'P_N0N3!!-H<P`H*V```#0\!@@/@!"<#'P2F.@``/I(?``H#'`0FDAY
M/[D('`)8Z%\0G0@``D"/@""J2'P`*`QP$),+DPH<#X`0'-.3'_@T'`!ZBGP@
M<@QX$),K8```-#P&"`^`$)P+DP0<TYP?H@@<`E-(?#^Q#Y,2@$A\`"@WG``"
M#'`0DPN3"AQH?``PZ```2@QX$)PWG``(#'P2F`QX$),.8!"3#',2D`QP$)R/
M@#[5"``"0&A@`#!(?``P2&(_V31^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!
M`(!H>C^Y2'H_N31\`!`('`)9Z%\='0@``D!(8C_9-'X`@$_#/X'H0,`":\(_
MV0@#`D$('@)#;\$!`&AD`$!H>C^Y:'D_L4AA/[$,(!`<TY,?^#0<`'J*?"`2
M2',_L39S``)H<S^Q2'H_L>A?$*T(``)`#'P2D#1\`!A(>C^Y"!P"6>A?'#T(
M``)`:'P`,$AT`#"&@"#22'H`,.A?$$T(``)`"!P"4PQP$)R*?*-"2&$_L0P@
M$!S3G!_X2',`,`Y\$@!(=``P#H`0'-.<'_B3G"``-!P``M.<&_A(80`P-"$`
M`FAA`#!(<S^Q-G,``FAS/[&/@#]M"``"0&A@`#CH``6Z*V```#0\!@@/@!"<
M:'P`(&A@`"CH```J2'0`(#:4``AH=``@2'P`*#><``)H?``H2&$`(`P@$)R/
M@#^U"``"0"M@```T/`90#X`0G(>`(+(K8```-#P&"`^`$)-(=``H-IP`!-><
M"$(($P):"!P"6>A?$'T(``)`"!P"4RM@```(`0)<-YP&"`^3$H`K8```"`$"
M7#><!@@/@!"<CX`A"C03/_]H<P`XZ``$8BM@```T,P90-!P``@Y\$H!(=``H
M-IP`!-><"$(('`):Z%\0A0@``D!H?``@2'P`((^`(!(T`3__:&$`..@``^(K
M8```-#P&"`^`$)-(?``HUYP(0DAZ`"`($P)9"!P"6.A?#R4(``)`*V````@!
M`EPWG`8(2',`(`^3$H`K8```-#P&"`^`$)-(?``H-YP``M><"$(+DPH<#X`2
M@$A\`"@,?!*82'0_N6AT`##H```22'P`,#><``)H?``P2&$`,`P@$!S3G!_X
MAX`@*DAS`#`.8!`<TY,?^#0<`'J*?#^="``"0"M@```T/`8(#X`0DPQX$)S7
MG`A""Y,*!$AS`#!(?#^Y"Y,$'`@<`E,,<!"<"Y,*'#><``0('`):Z%\.C0@`
M`D`,G!*`#(`0G(^`(!(T%#__:'0`..@``>HK8```-#P&"`^`$),,>!"<UYP(
M0@N3"AP/@!"<:'P`,.@``!)(?``P-YP``FA\`#!(?#^Y#X`0'-.<'_A(80`P
M##P2`$AS`#`.8!`<TYP?^).<(``T'``"TY,;^$A\/[DWG``":'P_N30<``(+
MDP*<TYP;^(^`("I(=``P#H`0'-.3'_@T'`!ZBGP_+0@``D`T'`!Z2&$`,`P\
M$@!(<P`P-G,``FAS`#!(=#^Q#H`0'-.<'_A(80`P##P2`$AS`#`.8!`<TYP?
M^).<(``T'``"TYP;^$AT`#`VE``":'0`,$AA/[$T(0`":&$_L8^`/VT(``)`
M:&``.$A\`#A(8C_92&0`0#1^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!`(!H
M>C^YZ```DBM@```T/`8(#X`0DPQP$)S7G`A""Y,*$PQS$I@,>!"3-GP`"`^`
M$)P,>!"3#GP2@`QX$),.8!"<AX`@&@QX$)PWG``(#'P2F.@?'Y](>C^Y-'P`
M$`@<`EGH7Q1M"``"0(^`/S4(``)`2&(_V31^`(!/PS^!Z$#``FO"/]D(`P)!
M"!X"0V_!/X`WW@&`#&`2F.A?!YT(``)`"!P"4S1\`"`('`):(XL@`#>9#(@(
M$P)8(XL@`#>7#*#H7PC-"``"0`Q\$I`,<!"<AX!@(B)B```V<P`I"',*$PY@
M$H#H``%:-'P`(#1S("(('`):"!,"6308(`#H7PL5"``"0`Q\$I`,<!"<AX!@
M(B."```WG``I"'P*'`^`$H#H``#B#'`0G#><``(('`):Z%\)K0@``D`,?!*8
M#'@0G(^`("(B8@``-G,`*0AS"A,.8!*`Z```>@QP$),T?"`B#'@0F@@<`ED(
M$P)8Z%\*E0@``D`,<!"3#'@0G`I\"AP/@!(`#'@0DR."```WG``I"'P*'`^3
M$H`B8@``-G,`*0AS"A,.8!"<2&(_V31^`(!/PS^!Z$#``FO"/]D(`P)!"!X"
M0V_!`(#H7QUE"``"0$AB/]DT?@"`3\,_@>A`P`)KPC_9"`,"00@>`D-OP2$`
M:'H_N6AY/[$CBR``-YH,J.A?$\4(``)`#'P2D"M@```(`0)<-YP`$`^`$)Q(
M>C^Y"!P"6>A?!H4(``)`AX`@.B.+(``WF@S`2'D_N>A?$[T(``)`2'P_N6A\
M(##H``3B2'H_N>A?!,4(``)`:'P`("M@```(`0)<-YP`&`^`$)Q(>C^Q"!P"
M6>A?![T(``)`:'P`*.@`!")(?``H#X`0'-.<'_B/@"`2(XL@`#><#.!H?``H
M#'`0G(>`(&H,<!":2'D`*.A?`\4(``)`CX`@0BM@```T/``8#X`0G#0:```(
M'`)9Z%\'!0@``D!H?``HZ``#:DAZ`"CH7P.="``"0`Q\$ICH```R#'@0G#><
M/_\,?!*8#'@0DTA\`"@*?`H<#X`2``QX$)PWDS__2'P`*`I\"AP/@!`<TY,?
M^"M@```T/``0#X`0G`^`$!S3G!_X@GP_90@``D`,>!"<-Y,``DA\`"`+DPH3
M-!P?_HI\0#HCBR``-YH,P$AY/[GH7Q%="``"0$A\/[EH?"`PZ``"@BM@```T
M/``0#X`0E#1S`#!(?#^Y:]P_F0@3`EHCBR``-YD,Z$AX`"@(%`)7Z%\"]0@`
M`D`T&@``Z%\$?0@``D`/@!"<"!P"6NA?'QD(``)`"!P"6NA?`V4(``)`"!P"
M4S1\`#`('`):"!,"6>A"%Y`(``)`CX`A`C0:``#H7P/U"``"0`^`$)P('`):
MZ%\>D0@``D`('`):Z%\"W0@``D!+DP`@(X<@``N3`A,CA```BGP@BC1\`#`(
M'`):-!D``NA?'VD(``)`CX`@6C1S`#`CBR``-YH,P`@3`EGH7P]]"``"0#1\
M`#`('`):Z%\?<0@``D!H?"`PZ```BBM@```T/``8#X`0G#0:```('`)9Z%\#
MC0@``D!H?``H2'P`*(^`.\4(``)`(XL@`#>:#,!(>3^YZ%\.S0@``D!(83^Y
M:&$@,$A\(#!(8C_9-'X`@$_#/X'H0,`""`,"00@>`D-OP0"`:'H_N4A\/[D,
M?!*82'P_N0Q\$I#H``!R#'`0G`^`$!S3DQ_X*V```#0\`!`/@!"<#X`0'-.<
M'_B*?"`2#'`0G#><``(,?!*8#'`0G#><``(,?!*0#'`0G`^`$!S3G!_XCX`_
M90@``D`,>!"<-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$`@&AZ/[E(?#^Y
MAX`@&DA\/[D/@!`<TYP?^(^`("HCBR``-YH,X.A?'2D(``)`#'P2F.@``TI(
M>C^YZ%\>(0@``D`WDS__2'P_N0I\"AP,?!*0Z```$@QP$($T(3__#&$2D$A\
M/[D,<!"3BGR`:@QP$($,(!`<TY,?^"M@```T/``0#X`0G`^`$!S3G!_X@GP_
MA0@``D#H```2#'`0DS9S/_\,<Q*02'P_N0QP$(&(/(!*#'`0DPY@$!S3DQ_X
M*V```#0\`!`/@!"<#X`0'-.<'_B*?#^%"``"0$A\/[D,<!"!B#P@L@QP$),.
M8!`<TY,?^"M@```T/``0#X`0G`^`$!S3G!_XBGP@*B.+(``WF@S@Z%\;40@`
M`D`,?!*8Z``!<BM@```T/``0#X`0G`@<`EKH7QL1"``"0`Q\$ICH``$R#'`0
MG#></_\,?!*02'P_N0QP$(&(/(!*#'`0DPY@$!S3DQ_X*V```#0\`!`/@!"<
M#X`0'-.<'_B"?#^%"``"0`QP$)-(?#^Y"Y,$'#><``0('`)3-!P@`(I\@`H,
M8!*8Z```:@QP$)-(?#^Y"Y,$'#><``(K8```-#H&6$AY/[D('`)8Z%\9R0@`
M`D`K8```"`$"7#><!E@,?!*8#'@0G$AB/]DT?@"`3\,_@>A`P`)KPC_9"`,"
M00@>`D-OP0$`(XL@`#><#G@T<P`8-!0`1`@3`EH('`)9"!0"6.A?'ED(``)`
M(XL@`#>:#/CH7Q"E"``"0".+(``WF@T8Z%\0A0@``D`CBR``-YH,J.A?$&4(
M``)`(XL@`#>:#3#H7Q!%"``"0".+(``WF@U(Z%\0)0@``D`CBR``-YH-8.A?
M$`4(``)`(XL@`#>:#,#H7P_E"``"0".+(``WF@UXZ%\/Q0@``D`CBR``-YH-
MD.A?#Z4(``)`(XL@`#>:#:CH7P=U"``"0`Q\$I`,<!"<AX`@(B.+(``WF@U(
M#'`0F>A?!Z4(``)`(XL@`#>:#=#H7P<5"``"0`Q\$I`,<!"<AX`@(B.+(``W
MF@WX#'`0F>A?!T4(``)`(XL@`#>:#A#H7P:U"``"0`Q\$I`,<!"<AX`@*B.+
M(``WF@RH#'`0F>A?!N4(``)`Z```ZB.+(``WF@XPZ%\&30@``D`,?!*0#'`0
MG(>`("HCBR``-YH-,`QP$)GH7P9]"``"0.@``((T?``8-YP`(@Q\$I`,<!":
M(XL@`#>9#E@T&``4Z%\5(0@``D"/@"`R#'`0G#>3`!0CBR``-YH-,`@3`EGH
M7P7M"``"0".+(``WF@SX(XL@`#>9#G#H7P6]"``"0$AB/]DT?@"`3\,_@>A`
MP`)KPC_9"`,"00@>`D-OP0"`*V```#0\`"`/@!"<CY\@NB.+(``WF@TPZ%\$
MS0@``D`,?!*0#'`0G(>`(%H,<!"<#X`0'-.<'_B'@"`Z#'`0G`^`$!S3DQ_X
M-!P`8()\(!(T$P`"#',2F.@```(,8!*8*V```#0\`"`,>!"3#Y,2@"M@```T
M/``@#X`0G$AB/]DT?@"`3\,_@>A`P`((`P)!"!X"0V_!`X!H>C^Y2'P_N3><
M`#AH?`!(:&``4.@``'I(?`!(#X`0G&A\`$!(?`!(-YP`"&A\`$A(?`!0UGP(
M0C1\`!`*?`H<-Y,`2$A\`$`.?!*`2'P`4#><``)H?`!02'P`4(^>7VT(``)`
M-!P`(&A\`%#H``&B2'4`4$A\`%`WG#_[UGP(0C1\`!`*?`H<-YP`2`^`$)1(
M?`!0-YP_\=9\"$(T?``0"GP*'#><`$@/@!"<"Y0"E$A\`%`WG#_EUGP(0C1\
M`!`*?`H<-YP`2`^`$)P+E`*42'P`4#></^'6?`A"-'P`$`I\"APWG`!(#X`0
MG`N4`I36=0A"-'P`$`I\"APWG`!(#Y02@$AU`%!(?`!0UGP(0C1\`!`*?`H<
M-YP`2`^`$)S3G`@4UG4(0C1\`!`*?`H<-YP`2`^4$H!(?`!0-YP``FA\`%!(
M<P!0-!P`GHI\7CT(``)`2'P_N0^`$)QH?``X2'P_N0^($)QH?``P2'P_N0^0
M$)QH?``H2'P_N0^8$)QH?``@2'P_N4N<`"`,?!*8-'P`6`Q\$I!(?``XTYP(
ME4AS`#!(?``H"Y,"%$A\`#`+@`F32'P`(`N3`AP+E`)<"Y4*$PQX$)P+DPH3
M#'`0G`^`$)P+DPH3(Y0+4#><,S,+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3
MG`N\:'P`,$A\`$#3G`B52',`.$A\`#`+DP(42'P`.`N`"9-(?``H"Y,"'`N4
M`EP+E0H32'P`(`N3"A,,<!"<#X`0G`N3"A,CE`M0-YPS,PN3"AP,?!*8#'`0
MG#><``@,?!*02'P`.-.<"[QH?``X#'@0G-.<")5(<P!`2'P`.`N3`A1(?`!`
M"X`)DTA\`#`+DP(<"Y0"7`N5"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.4"U`W
MG#,S"Y,*'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E0QX
M$)-(?`!`"Y,"%`QX$)P+@`F32'P`.`N3`AP+E`)<"Y4*$TA\`#`+DPH3#'`0
MG`^`$)P+DPH3(Y0+4#><,S,+DPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3G`N\
M#'P2F$A\`"C3G`B52',`(`QX$)P+DP(42'P`(`N`"9-(?`!`"Y,"'`N4`EP+
ME0H32'P`.`N3"A,,<!"<#X`0G`N3"A,CE`M0-YPS,PN3"AQH?``P#'`0G#><
M``@,?!*02'P`(-.<"[QH?``@2'P`,-.<")5(<P`H2'P`(`N3`A1(?``H"X`)
MDPQX$)P+DP(<"Y0"7`N5"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.4"U`WG#,S
M"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(E4AS`#!(
M?``H"Y,"%$A\`#`+@`F32'P`(`N3`AP+E`)<"Y4*$PQX$)P+DPH3#'`0G`^`
M$)P+DPH3(Y0+4#><,S,+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`
M,$A\`$#3G`B52',`.$A\`#`+DP(42'P`.`N`"9-(?``H"Y,"'`N4`EP+E0H3
M2'P`(`N3"A,,<!"<#X`0G`N3"A,CE`M0-YPS,PN3"AP,?!*8#'`0G#><``@,
M?!*02'P`.-.<"[QH?``X#'@0G-.<")5(<P!`2'P`.`N3`A1(?`!`"X`)DTA\
M`#`+DP(<"Y0"7`N5"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*
M'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E0QX$)-(?`!`
M"Y,"%`QX$)P+@`F32'P`.`N3`AP+E`)<"Y4*$TA\`#`+DPH3#'`0G`^`$)P+
MDPH3(Y0+4#><,S,+DPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3G`N\#'P2F$A\
M`"C3G`B52',`(`QX$)P+DP(42'P`(`N`"9-(?`!`"Y,"'`N4`EP+E0H32'P`
M.`N3"A,,<!"<#X`0G`N3"A,CE`M0-YPS,PN3"AQH?``P#'`0G#><``@,?!*0
M2'P`(-.<"[QH?``@2'P`,-.<")5(<P`H2'P`(`N3`A1(?``H"X`)DPQX$)P+
MDP(<"Y0"7`N5"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\
M`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(E4AS`#!(?``H"Y,"
M%$A\`#`+@`F32'P`(`N3`AP+E`)<"Y4*$PQX$)P+DPH3#'`0G`^`$)P+DPH3
M(Y0+4#><,S,+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`,$A\`$#3
MG`B52',`.$A\`#`+DP(42'P`.`N`"9-(?``H"Y,"'`N4`EP+E0H32'P`(`N3
M"A,,<!"<#X`0G`N3"A,CE`M0-YPS,PN3"AP,?!*8#'`0G#><``@,?!*02'P`
M.-.<"[QH?``X#'@0G-.<")5(<P!`2'P`.`N3`A1(?`!`"X`)DTA\`#`+DP(<
M"Y0"7`N5"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`"`,
M<!"<-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E0QX$)-(?`!`"Y,"%`QX
M$)P+@`F32'P`.`N3`AP+E`)<"Y4*$TA\`#`+DPH3#'`0G`^`$)P+DPH3(Y0+
M4#><,S,+DPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3G`N\#'P2F$A\`"C3G`B5
M2',`(`QX$)P+DP(42'P`(`N`"9-(?`!`"Y,"'`N4`EP+E0H32'P`.`N3"A,,
M<!"<#X`0G`N3"A,CE`M0-YPS,PN3"AQH?``P#'`0G#><``@,?!*02'P`(-.<
M"[QH?``@2'P`,-.<")5(<P`H2'P`(`N3`A1(?``H"X`)DPQX$)P+DP(<"Y0"
M7`N5"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.4"U`WG#,S"Y,*'&A\`#@,<!"<
M-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(E4AS`#!(?``H"Y,"%$A\`#`+
M@`F32'P`(`N3`AP+E`)<"Y4*$PQX$)P+DPH3#'`0G`^`$)P+DPH3(Y0+4#><
M,S,+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`,$A\`$#3G`B52',`
M.$A\`#`+DP(42'P`.`N`"9-(?``H"Y,"'`N4`EP+E0H32'P`(`N3"A,,<!"<
M#X`0G`N3"A,CE`M0-YPS,PN3"AP,?!*8#'`0G#><``@,?!*02'P`.-.<"[QH
M?``X#'@0G-.<")1(<P!`2'P`.`N3`I-(?``P"Y,"G`N4"A-(?``H"Y,*$PQP
M$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+
MO&A\`$!(?``@TYP(E`QX$)-(?`!`"Y,"DTA\`#@+DP*<"Y0*$TA\`#`+DPH3
M#'`0G`^`$)P+DPH3(Y"-VC><%T,+DPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3
MG`N\#'P2F$A\`"C3G`B42',`(`QX$)P+DP*32'P`0`N3`IP+E`H32'P`.`N3
M"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AQH?``P#'`0G#><``@,?!*02'P`
M(-.<"[QH?``@2'P`,-.<")1(<P`H2'P`(`N3`I,,>!"<"Y,"G`N4"A-(?`!`
M"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(
M?``HTYP+O&A\`"A(?``XTYP(E$AS`#!(?``H"Y,"DTA\`"`+DP*<"Y0*$PQX
M$)P+DPH3#'`0G`^`$)P+DPH3(Y"-VC><%T,+DPH<:'P`0`QP$)PWG``(#'P2
MD$A\`##3G`N\:'P`,$A\`$#3G`B42',`.$A\`#`+DP*32'P`*`N3`IP+E`H3
M2'P`(`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AP,?!*8#'`0G#><``@,
M?!*02'P`.-.<"[QH?``X#'@0G-.<")1(<P!`2'P`.`N3`I-(?``P"Y,"G`N4
M"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`"`,<!"<-YP`
M"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E`QX$)-(?`!`"Y,"DTA\`#@+DP*<
M"Y0*$TA\`#`+DPH3#'`0G`^`$)P+DPH3(Y"-VC><%T,+DPH<:'P`*`QP$)PW
MG``(#'P2D`QX$)S3G`N\#'P2F$A\`"C3G`B42',`(`QX$)P+DP*32'P`0`N3
M`IP+E`H32'P`.`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AQH?``P#'`0
MG#><``@,?!*02'P`(-.<"[QH?``@2'P`,-.<")1(<P`H2'P`(`N3`I,,>!"<
M"Y,"G`N4"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*'&A\`#@,
M<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(E$AS`#!(?``H"Y,"DTA\
M`"`+DP*<"Y0*$PQX$)P+DPH3#'`0G`^`$)P+DPH3(Y"-VC><%T,+DPH<:'P`
M0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`,$A\`$#3G`B42',`.$A\`#`+DP*3
M2'P`*`N3`IP+E`H32'P`(`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP70PN3"AP,
M?!*8#'`0G#><``@,?!*02'P`.-.<"[QH?``X#'@0G-.<")1(<P!`2'P`.`N3
M`I-(?``P"Y,"G`N4"A-(?``H"Y,*$PQP$)P/@!"<"Y,*$R.0C=HWG!=#"Y,*
M'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@TYP(E`QX$)-(?`!`
M"Y,"DTA\`#@+DP*<"Y0*$TA\`#`+DPH3#'`0G`^`$)P+DPH3(Y"-VC><%T,+
MDPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3G`N\#'P2F$A\`"C3G`B42',`(`QX
M$)P+DP*32'P`0`N3`IP+E`H32'P`.`N3"A,,<!"<#X`0G`N3"A,CD(W:-YP7
M0PN3"AQH?``P#'`0G#><``@,?!*02'P`(-.<"[QH?``@2'P`,-.<")1(<P`H
M2'P`(`N3`I,,>!"<"Y,"G`N4"A-(?`!`"Y,*$PQP$)P/@!"<"Y,*$R.0C=HW
MG!=#"Y,*'&A\`#@,<!"<-YP`"`Q\$I!(?``HTYP+O&A\`"A(?``XTYP(E$AS
M`#!(?``H"Y,"DTA\`"`+DP*<"Y0*$PQX$)P+DPH3#'`0G`^`$)P+DPH3(Y"-
MVC><%T,+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`,$A\`$#3G`B4
M2',`.$A\`#`+DP*32'P`*`N3`IP+E`H32'P`(`N3"A,,<!"<#X`0G`N3"A,C
MD(W:-YP70PN3"AP,?!*8#'`0G#><``@,?!*02'P`.-.<"[QH?``X#'@0G-.<
M")1(<P!`2'P`.`N3`I-(?``P"Y,"G`N4"A-(?``H"Y,*$PQP$)P/@!"<"Y,*
M$R.0C=HWG!=#"Y,*'&A\`"`,<!"<-YP`"`Q\$I!(?`!`TYP+O&A\`$!(?``@
MTYP(E`QX$)-(?`!`"Y,"DTA\`#@+DP*<"Y0*$TA\`#`+DPH3#'`0G`^`$)P+
MDPH3(Y"-VC><%T,+DPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3G`N\#'P2F$A\
M`"C3G`B5#'@0DTA\`$`+DP)32'P`(`N3`A0,>!"32'P`0`N3`AP+E`)<"Y4*
M$TA\`#@+DPH3#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<:'P`,`QP$)PWG``(
M#'P2D$A\`"#3G`N\:'P`($A\`##3G`B52',`(`QX$)P+DP)32'P`*`N3`A1(
M<P`@#'@0G`N3`AP+E`)<"Y4*$TA\`$`+DPH3#'`0G`^`$)P+DPH3(YZ!XS><
M.;D+DPH<:'P`.`QP$)PWG``(#'P2D$A\`"C3G`N\:'P`*$A\`#C3G`B52',`
M*$A\`"`+DP)32'P`,`N3`A1(<P`H2'P`(`N3`AP+E`)<"Y4*$PQX$)P+DPH3
M#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3
MG`N\:'P`,$A\`$#3G`B52',`,$A\`"@+DP)32'P`.`N3`A1(<P`P2'P`*`N3
M`AP+E`)<"Y4*$TA\`"`+DPH3#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<#'P2
MF`QP$)PWG``(#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B52',`.$A\`#`+DP)3
M2'P`0`N3`A1(<P`X2'P`,`N3`AP+E`)<"Y4*$TA\`"@+DPH3#'`0G`^`$)P+
MDPH3(YZ!XS><.;D+DPH<:'P`(`QP$)PWG``(#'P2D$A\`$#3G`N\:'P`0$A\
M`"#3G`B52',`0$A\`#@+DP)3#'@0G`N3`A1(<P!`2'P`.`N3`AP+E`)<"Y4*
M$TA\`#`+DPH3#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<:'P`*`QP$)PWG``(
M#'P2D`QX$)S3G`N\#'P2F$A\`"C3G`B5#'@0DTA\`$`+DP)32'P`(`N3`A0,
M>!"32'P`0`N3`AP+E`)<"Y4*$TA\`#@+DPH3#'`0G`^`$)P+DPH3(YZ!XS><
M.;D+DPH<:'P`,`QP$)PWG``(#'P2D$A\`"#3G`N\:'P`($A\`##3G`B52',`
M(`QX$)P+DP)32'P`*`N3`A1(<P`@#'@0G`N3`AP+E`)<"Y4*$TA\`$`+DPH3
M#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<:'P`.`QP$)PWG``(#'P2D$A\`"C3
MG`N\:'P`*$A\`#C3G`B52',`*$A\`"`+DP)32'P`,`N3`A1(<P`H2'P`(`N3
M`AP+E`)<"Y4*$PQX$)P+DPH3#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<:'P`
M0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`,$A\`$#3G`B52',`,$A\`"@+DP)3
M2'P`.`N3`A1(<P`P2'P`*`N3`AP+E`)<"Y4*$TA\`"`+DPH3#'`0G`^`$)P+
MDPH3(YZ!XS><.;D+DPH<#'P2F`QP$)PWG``(#'P2D$A\`#C3G`N\:'P`.`QX
M$)S3G`B52',`.$A\`#`+DP)32'P`0`N3`A1(<P`X2'P`,`N3`AP+E`)<"Y4*
M$TA\`"@+DPH3#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<:'P`(`QP$)PWG``(
M#'P2D$A\`$#3G`N\:'P`0$A\`"#3G`B52',`0$A\`#@+DP)3#'@0G`N3`A1(
M<P!`2'P`.`N3`AP+E`)<"Y4*$TA\`#`+DPH3#'`0G`^`$)P+DPH3(YZ!XS><
M.;D+DPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3G`N\#'P2F$A\`"C3G`B5#'@0
MDTA\`$`+DP)32'P`(`N3`A0,>!"32'P`0`N3`AP+E`)<"Y4*$TA\`#@+DPH3
M#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<:'P`,`QP$)PWG``(#'P2D$A\`"#3
MG`N\:'P`($A\`##3G`B52',`(`QX$)P+DP)32'P`*`N3`A1(<P`@#'@0G`N3
M`AP+E`)<"Y4*$TA\`$`+DPH3#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<:'P`
M.`QP$)PWG``(#'P2D$A\`"C3G`N\:'P`*$A\`#C3G`B52',`*$A\`"`+DP)3
M2'P`,`N3`A1(<P`H2'P`(`N3`AP+E`)<"Y4*$PQX$)P+DPH3#'`0G`^`$)P+
MDPH3(YZ!XS><.;D+DPH<:'P`0`QP$)PWG``(#'P2D$A\`##3G`N\:'P`,$A\
M`$#3G`B52',`,$A\`"@+DP)32'P`.`N3`A1(<P`P2'P`*`N3`AP+E`)<"Y4*
M$TA\`"`+DPH3#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<#'P2F`QP$)PWG``(
M#'P2D$A\`#C3G`N\:'P`.`QX$)S3G`B52',`.$A\`#`+DP)32'P`0`N3`A1(
M<P`X2'P`,`N3`AP+E`)<"Y4*$TA\`"@+DPH3#'`0G`^`$)P+DPH3(YZ!XS><
M.;D+DPH<:'P`(`QP$)PWG``(#'P2D$A\`$#3G`N\:'P`0$A\`"#3G`B52',`
M0$A\`#@+DP)3#'@0G`N3`A1(<P!`2'P`.`N3`AP+E`)<"Y4*$TA\`#`+DPH3
M#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<:'P`*`QP$)PWG``(#'P2D`QX$)S3
MG`N\#'P2F$A\`"C3G`B5#'@0DTA\`$`+DP)32'P`(`N3`A0,>!"32'P`0`N3
M`AP+E`)<"Y4*$TA\`#@+DPH3#'`0G`^`$)P+DPH3(YZ!XS><.;D+DPH<:'P`
M,`QP$)PWG``(#'P2D$A\`"#3G`N\:'P`($A\`##3G`B52',`(`QX$)P+DP)3
M2'P`*`N3`A1(<P`@#'@0G`N3`AP+E`)<"Y4*$TA\`$`+DPH3#'`0G`^`$)P+
MDPH3(YZ!XS><.;D+DPH<:'P`.`QP$)PWG``(#'P2D$A\`"C3G`N\:'P`*$A\
M`#C3G`B42',`,$A\`"@+DP*32'P`(`N3`IP+E`H3#'@0G`N3"A,,<!"<#X`0
MG`N3"A,CE@E--YP#K`N3"AQH?`!`#'`0G#><``@,?!*02'P`,-.<"[QH?``P
M2'P`0-.<")1(<P`X2'P`,`N3`I-(?``H"Y,"G`N4"A-(?``@"Y,*$PQP$)P/
M@!"<"Y,*$R.6"4TWG`.L"Y,*'`Q\$I@,<!"<-YP`"`Q\$I!(?``XTYP+O&A\
M`#@,>!"<TYP(E$AS`$!(?``X"Y,"DTA\`#`+DP*<"Y0*$TA\`"@+DPH3#'`0
MG`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`(`QP$)PWG``(#'P2D$A\`$#3G`N\
M:'P`0$A\`"#3G`B4#'@0DTA\`$`+DP*32'P`.`N3`IP+E`H32'P`,`N3"A,,
M<!"<#X`0G`N3"A,CE@E--YP#K`N3"AQH?``H#'`0G#><``@,?!*0#'@0G-.<
M"[P,?!*82'P`*-.<")1(<P`@#'@0G`N3`I-(?`!`"Y,"G`N4"A-(?``X"Y,*
M$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*'&A\`#`,<!"<-YP`"`Q\$I!(?``@
MTYP+O&A\`"!(?``PTYP(E$AS`"A(?``@"Y,"DPQX$)P+DP*<"Y0*$TA\`$`+
MDPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`.`QP$)PWG``(#'P2D$A\
M`"C3G`N\:'P`*$A\`#C3G`B42',`,$A\`"@+DP*32'P`(`N3`IP+E`H3#'@0
MG`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3"AQH?`!`#'`0G#><``@,?!*0
M2'P`,-.<"[QH?``P2'P`0-.<")1(<P`X2'P`,`N3`I-(?``H"Y,"G`N4"A-(
M?``@"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*'`Q\$I@,<!"<-YP`"`Q\
M$I!(?``XTYP+O&A\`#@,>!"<TYP(E$AS`$!(?``X"Y,"DTA\`#`+DP*<"Y0*
M$TA\`"@+DPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`(`QP$)PWG``(
M#'P2D$A\`$#3G`N\:'P`0$A\`"#3G`B4#'@0DTA\`$`+DP*32'P`.`N3`IP+
ME`H32'P`,`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3"AQH?``H#'`0G#><
M``@,?!*0#'@0G-.<"[P,?!*82'P`*-.<")1(<P`@#'@0G`N3`I-(?`!`"Y,"
MG`N4"A-(?``X"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*'&A\`#`,<!"<
M-YP`"`Q\$I!(?``@TYP+O&A\`"!(?``PTYP(E$AS`"A(?``@"Y,"DPQX$)P+
MDP*<"Y0*$TA\`$`+DPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<:'P`.`QP
M$)PWG``(#'P2D$A\`"C3G`N\:'P`*$A\`#C3G`B42',`,$A\`"@+DP*32'P`
M(`N3`IP+E`H3#'@0G`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3"AQH?`!`
M#'`0G#><``@,?!*02'P`,-.<"[QH?``P2'P`0-.<")1(<P`X2'P`,`N3`I-(
M?``H"Y,"G`N4"A-(?``@"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L"Y,*'`Q\
M$I@,<!"<-YP`"`Q\$I!(?``XTYP+O&A\`#@,>!"<TYP(E$AS`$!(?``X"Y,"
MDTA\`#`+DP*<"Y0*$TA\`"@+DPH3#'`0G`^`$)P+DPH3(Y8)33><`ZP+DPH<
M:'P`(`QP$)PWG``(#'P2D$A\`$#3G`N\:'P`0$A\`"#3G`B4#'@0DTA\`$`+
MDP*32'P`.`N3`IP+E`H32'P`,`N3"A,,<!"<#X`0G`N3"A,CE@E--YP#K`N3
M"AQH?``H#'`0G#><``@,?!*0#'@0G-.<"[P,?!*82'P`*-.<")1(<P`@#'@0
MG`N3`I-(?`!`"Y,"G`N4"A-(?``X"Y,*$PQP$)P/@!"<"Y,*$R.6"4TWG`.L
M"Y,*'&A\`#`,<!"<-YP`"`Q\$I!(?``@TYP+O&A\`"!(?``PTYP(E$AS`"A(
M?``@"Y,"DPQX$)P+DP*<"Y0*$TA\`$`+DPH3#'`0G`^`$)P+DPH3(Y8)33><
M`ZP+DPH<:'P`.`QP$)PWG``(#'P2D$A\`"C3G`N\:'P`*$A\`#C3G`B42',`
M,$A\`"@+DP*32'P`(`N3`IP+E`H3#'@0G`N3"A,,<!"<#X`0G`N3"A,CE@E-
M-YP#K`N3"AQH?`!`#'`0G#><``@,?!*02'P`,-.<"[QH?``P2'P`0-.<")1(
M<P`X2'P`,`N3`I-(?``H"Y,"G`N4"A-(?``@"Y,*$PQP$)P/@!"<"Y,*$R.6
M"4TWG`.L"Y,*'`Q\$I@,<!"<-YP`"`Q\$I!(?``XTYP+O&A\`#A(?#^Y#X`0
MDPQX$)P+DPH32'P_N0^3$H!(?#^Y#X@0DTA\`$`+DPH32'P_N0^3$HA(?#^Y
M#Y`0DTA\`#@+DPH32'P_N0^3$I!(?#^Y#Y@0DTA\`#`+DPH32'P_N0^3$IA(
M?#^Y2Y,`($A\`"@+DPH32'P_N6N3`"`T?@"`3\,_@>A`P`((`P)!"!X"0V_!
M`(!H>C^Y2',_N2.*3.@WG`8##GP2@$AS/[DCCLWY-YP7$PY\$HA(<S^Y(Y:#
M%S><.?P.?!*02',_N2.2`@8WG"CL#GP2F$AS/[DCF`A[-YP#X6I\`"!(?#^Y
M:X``*$A\/[EK@``P2'P_N6N``+@T?@"`3\,_@>A`P`)KPC_9"`,"00@>`D-O
MP0"`:'H_N6AY/[%H>#^I2'P_N4N3`"A(?#^IUYP(8PN3"AP,?!*02'P_N4N3
M`"@,<!"<BGR`(DA\/[E+G``P-Y,``DA\/[EKDP`P2',_N0QP$)QJ?``H2'P_
MN4N3`#!(?#^ITYP870N3"A-(?#^Y:Y,`,$A\/[E+G`"XAX`ARDA\/[E+G`"X
MEYP`@`Q\$I@,>!"32'P_J8I\0`I(?#^I#'P2F$A\/[DWDP`X2'P_N4N<`+@+
MDPH<#'@0DP@<`EI(>3^Q"!,"6.A>%*D(``)`2',_J0QX$)P+DP0<:'P_J0QX
M$)-(?#^Q"GP*'&A\/[%(?#^Y2Y,`N`QX$)P+DPH32'P_N6N3`+A(?#^Y2Y,`
MN#0<`("*?"$22'H_N>A>&FT(``)`Z```>DA\/[DWG``X"!P"6DAY/[$T&`"`
MZ%X3P0@``D!(?#^Q-YP`@&A\/[%(?#^I-YP_@6A\/ZE(>C^YZ%X9Y0@``D!(
M<S^I-!P`?H)\7V4(``)`2'P_N3><`#A(<S^I"!P"6DAY/[$($P)8Z%X3&0@`
M`D!(<S^Y2'P_J6I\`+A(8C_9-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$`
M@&AZ/[EH>3^Q2'H_L>A>&04(``)`2'P_L0^`$)S3G!CXTY,;^$A\/[D/DQ(`
M2'P_N3>3``)(?#^Q#X`0G-.<&?#3G!OX#GP2`$A\/[DWDP`$2'P_L0^`$)S3
MG!KHTYP;^`Y\$@!(?#^Y-Y,`!DA\/[$/@!"<TYP;^`Y\$@!(?#^Y-Y,`"$A\
M/[$/B!"<TYP8^-.<&_@.?!(`2'P_N3>3``I(?#^Q#X@0G-.<&?#3G!OX#GP2
M`$A\/[DWDP`,2'P_L0^($)S3G!KHTYP;^`Y\$@!(?#^Y-Y,`#DA\/[$/B!"<
MTYP;^`Y\$@!(?#^Y-Y,`$$A\/[$/D!"<TYP8^-.<&_@.?!(`2'P_N3>3`!)(
M?#^Q#Y`0G-.<&?#3G!OX#GP2`$A\/[DWDP`42'P_L0^0$)S3G!KHTYP;^`Y\
M$@!(?#^Y-Y,`%DA\/[$/D!"<TYP;^`Y\$@!(?#^Y-Y,`&$A\/[$/F!"<TYP8
M^-.<&_@.?!(`2'P_N3>3`!I(?#^Q#Y@0G-.<&?#3G!OX#GP2`$A\/[DWDP`<
M2'P_L0^8$)S3G!KHTYP;^`Y\$@!(?#^Y-Y,`'DA\/[$/F!"<TYP;^`Y\$@!(
M?#^Y-Y,`($A\/[%+G``@TYP8^-.<&_@.?!(`2'P_N3>3`")(?#^Q2YP`(-.<
M&?#3G!OX#GP2`$A\/[DWDP`D2'P_L4N<`"#3G!KHTYP;^`Y\$@!(?#^Y-Y,`
M)DA\/[%+G``@TYP;^`Y\$@!(8C_9-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#
M;\$!`&AZ/[EH>3^Q2'P_L4N<`"@,?!*82'P_L4N<`#`,?!*0#'@0G-.<&X/3
MG!OZ:'P`($A\/[$WDP`X2'P`(`N3"A,T'#\!#GP2`$A\`"`WG``":'P`($AS
M`"`T'`!PBGQ`JDA\/[$WDP`X2'P`(`N3"A-(?``@EYP`@`@3`EHT&0``"!P"
M6.A>!?$(``)`2'H_L>A>$V4(``)`2'P_L3><`#@('`):-!D``#08`'#H7@6A
M"``"0.@``%)(?#^Q-Y,`.$A\`"`+DPH32'P`()><`'`($P):-!D```@<`ECH
M7@5!"``"0`QP$)S3G!CXTY,;^$A\/[%CDP"H#'`0G-.<&?#3DQOX2'P_L6.3
M`*H,<!"<TYP:Z-.3&_A(?#^Q8Y,`K`QP$)S3DQOX2'P_L6.3`*X,>!"<TYP8
M^-.3&_A(?#^Q8Y,`L`QX$)S3G!GPTY,;^$A\/[%CDP"R#'@0G-.<&NC3DQOX
M2'P_L6.3`+0,>!"<TY,;^$A\/[%CDP"V2'H_N4AY/['H7Q@U"``"0$AB/]DT
M?@"`3\,_@>A`P`)KPC_9"`,"00@>`D-OP0"`#&`2F`Q@$I#H7@R1"``"0`@<
M`EKH7@2Y"``"0`Q\$I`,<!"<AX`@$@QP$)P/@!"<#'P2F`QX$)Q(8C_9-'X`
M@$_#/X'H0,`":\(_V0@#`D$('@)#;\$`@&AZ/[DT&@``Z%X(@0@``D`/@!"<
M"!P"6NA>`R$(``)`"!P"6NA>!VD(``)`2'H_N0@<`EGH0!OL"``"0(^`(2HT
M&@``Z%X("0@``D`/@!"<"!P"6NA>`JD(``)`"!P"6NA>!O$(``)`2Y,`(".'
M(``+DP(3(X(``()\('(T&@``Z%X'D0@``D`/@!"<"!P"6NA>`C$(``)`"!P"
M6NA>!GD(``)`2Y,`(".'(``+DP(3(X4``(I\(#I(>C^Y-!D`!.A>`Q$(``)`
MCX`@$C0<``(,?!*0Z````@Q@$I`,<!"<2&(_V31^`(!/PS^!Z$#``FO"/]D(
M`P)!"!X"0V_!`0!H9`!@:'H_N6A@`"AH8``@*WSO_S0\!8@T<P`P-!0`,`@3
M`EH('`)9"!0"6.A>![D(``)`#&`2D`Q@$ICH``'B2'H`*.A>$>$(``)`:'P`
M($A\`""'@"`:2'P`(`^`$!S3G!_XCX`@(DAZ`"A(>3^YZ%X1^0@``D#H``%2
M2'H`($AY/[GH7@1I"``"0(^`(2I(>C^YZ%X"Z0@``D`('`)$*V````@!`EPW
MG``8#X`0G`@<`EKH7@*I"``"0`N$"@1(>@`@Z%X"B0@``D`+A`H<-YP`!`@<
M`EKH7@4!"``"0`Q\$I`K8```"`$"7#><`!@/@!"32'P`(&O</YD,<!":(XL@
M`#>9#.A(>#^Y"!,"5^A>`M$(``)`2'H`*`QP$)GH7A"9"``"0`QX$)PWG``"
M#'P2F`QX$)S6?`A"-'P`$`I\"APWG``@#X`0G&A\`"A(?``H#X`0'-.<'_B/
M@#V]"``"0$AB/]E(9`!@-'X`@$_#/X'H0,`":\(_V0@#`D$('@)#;\$_@"O#
M```T/@.`*&0``&@E`D`H9```:"0"2&AZ/[EH8`!X:&``<&A@`&@K?.__-#P&
M0#1S`)`T%``@"!,"6@@<`ED(%`)8Z%X$>0@``D`K?.__"`$"7#><!?`T<P"P
M-!0`,`@3`EH('`)9"!0"6.A>!"D(``)`(XLP`#><`"AH?`#@(XLP`#><`#AH
M?`#H(XL@`#><#TAH?`#P(XLP`#><`%!H?`!@(XL@`#><#TAH?`!8:&``4&A@
M`$AH8`!`:&``(".+(``WF@RHZ%X-R0@``D!H?`!H2'P`:(>`(')(?`!H#X`0
M'-.<'_B'@"!22'H`:.A?&N4(``)`2'H`:.A='>T(``)`(F0``#9S`C@(<PH3
M#GP2@.@`#=+H7Q?E"``"0&A\`$A(?`!(CX`@XFA@`(CH``!B2'H`<.A>#.D(
M``)`:'P`:$A\`&B'@"`:2'H`:.A='44(``)`:'P`2$A\`(@WG``":'P`B$A\
M`$B/@"!:2'P`B-9\"$(T?``0"GP*'#><`-`/@!"<:'P`<$A\`'`/@!`<TYP?
M^(^`/RT(``)`2'P`2(^`(!HCBS``-YP`8&A\`$CH``#:2'P`2&A\`(#H``":
MZ%T>O0@``D`/@!"32'P`@`^`$!S3G!_XUYP((0N3"AP/@!!<TYP;\`@<`E,T
M'!``"Y,"'(^`(!)(<P"`-!P`O@Y\$@!(?`"`-YP``FA\`(!(?`"`#X`0'-.<
M'_B/@#\]"``"0&A@`(CH``""2'H`<.A>"O$(``)`:'P`:$A\`&B'@"`Z2'H`
M:.A?%BT(``)`AX`@&DAZ`&CH71LM"``"0&A\`'A(?`"(-YP``FA\`(A(?`!X
MCX`@6DA\`(C6?`A"-'P`$`I\"APWG`"@#X`0G&A\`'!(?`!P#X`0'-.<'_B/
M@#\-"``"0&A@`(CH``!22'H`:.A?%54(``)`AX`@&DAZ`&CH71I5"``"0&A\
M`'A(?`"(-YP``FA\`(A(?`!XCX`@6DA\`(C6?`A"-'P`$`I\"APWG`"`#X`0
MG&A\`&A(?`!H#X`0'-.<'_B/@#\]"``"0$AZ`'CH71K-"``"0`@<`D1(>@!@
MZ%T:K0@``D`+A`H$2'H`2.A=&HT(``)`"X0*!$AZ`%CH71IM"``"0`N$"APW
MG`@`:'P`($A\`"`('`):Z%T<U0@``D!H?`!`*V````@!`EPWG``0#X`0DTA\
M`&!KW#^92'P`2&O</Y%(>@!`(XLP`#>9`'!(>`!X"!,"5^A=&I4(``)`2'H`
M0#09`]KH71:U"``"0".+(``WF@\0Z%X'R0@``D!H?`!H2'P_N0^`$(1(>@!H
MZ%T8)0@``D`(!`):"!P"6>A>$VD(``)`:'P`4$A\`%"/@"`22'P_N0^`$)QH
M?`!0Z%X"%0@``D"/@"4"2'H`4#09``#H71N]"``"0&A\`#A(?``XAX`DRC0<
M``1KW#^92'H`.#07/_\T&#_=Z%T=S0@``D`T?`(02'H`.`@<`EDT&``,Z%T;
M'0@``D!`?`(0TYP;^(^`(:I`?`(2TY,;^#0<`(:*?"&*0'P"%-.3&_@T'`""
MBGPA:D!\`A;3DQOX-!P`AHI\(4I`?`(8TY,;^#0<`)"*?"$J0'P"&M.3&_@T
M'`"*BGPA"C0<``1KW#^92'H`.#07/_\T&#^-Z%T<K0@``D`T?`(02'H`.`@<
M`EDT&`!2Z%T9_0@``D!(>@!`Z%T7!0@``D`('`)32'P`0`I\"A,K8```"`$"
M7#><`!`/@!"4-'4"$$A\`%AKW#^9"!,"6B.+,``WF0"("!0"6`@5`E?H71==
M"``"0.@`!/HT?`%0"!P"6NA?`NT(``)`Z```,C1\`5`T<P(0"!P"6@@3`EE(
M>``PZ%\#M0@``D`T?`(02'H`.`@<`EDC!```Z%T8Q0@``D!H?``P2'P`,(>`
M7WT(``)`2'H`..A=&LT(``)`(X0``#>3`@`T?``0"GP*'#1S`5`('`):"!,"
M6>A?"QT(``)`:&``*.@``*I(?``HUYP((31T`/@+E`H42'4`*")D```T?``0
M"GP*'`J\"APWG`(`#X`0'-.<&_@('`)3"!0"6B.+,``WF0"H"!,"6.A=%9T(
M``)`2'P`*#><``)H?``H2',`*#0<`":*?%\U"``"0&!@`4A(>@!`Z%T490@`
M`D`('`)32'P`0`I\"A,K8```"`$"7#><`!`/@!"4-'4`^$A\`%AKW#^9"!,"
M6B.+,``WF0"("!0"6`@5`E?H712]"``"0.@``EH,8!*82'H`0.A=$[4(``)`
M#'P2D".+(``WF@TP(XL@`#>9#G#H7@)!"``"0$AZ`$#H71-E"``"0`@<`E-(
M?`!`"GP*!"M@```(`0)<-YP`$`^`$(7H71)]"``"0`@<`E-(?`!8:]P_F0@$
M`EHCBS``-YD`N`@%`E@($P)7Z%T3K0@``D#H``#R2',`0`QP$)P+DPH<#X`2
M`$AZ`$#H71*-"``"0`@<`E-(?`!`"GP*!"M@```(`0)<-YP`$`^`$(7H71&E
M"``"0`@<`E,,>!"<-YP``@Q\$I@,>!"<:]P_F4A\`%AKW#^1"`0"6B.+,``W
MF0#0"`4"6`@3`E?H71*M"``"0$AZ`$`T&0/:Z%T.S0@``D"/GR`JZ%T6U0@`
M`D`/@!"3-!P`(H)\/K4(``)`(XL@`#>:#*A(>0!`Z%X`$0@``D!(>@!`Z%\,
M]0@``D!(?`!`(F0``#9S`C@(<PH3#GP2@"`D```T(0(X"&$*`0P@$)Q(8C_9
M*&0``$@E`D`H9```2"0"2#1^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!`8!H
M9`$`:'H_N0Q@$IA(?#^YAX`BNDA\/[D/@!`<TYP?^(>`(II(>C^YZ%T-+0@`
M`D!H?``H2'P`*(>`(FKH``'Z2'P`(#><`"8('`):(XL@`#>9#.#H70^5"``"
M0(>`(;I(?``@-YP`)@@<`EHCBS``-YD`\.A=#U4(``)`AX`A>DAZ/[GH70]U
M"``"0`@<`D1(?``@-YP`)@@<`EKH70]%"``"0`N$"APWG``$#'P2D`QP$)P(
M'`):Z%T1K0@``D`,?!*82'P`(#>3`"8,>!":(XLP`#>9`/A(>#^Y"!,"5^A=
M#YT(``)`-'P`,`QX$)H('`)9Z$`$E`@``D"'GR!"2',`4".'(``+DP(3(X(`
M`(I\(!H,>!":Z%\=I0@``D#H```2#'@0FNA=$\T(``)`#'@0FNA=#?4(``)`
M#&`2F$AZ`"CH70X5"``"0&A\`"!(?``@CX`]S0@``D!(>@`HZ%T,_0@``D!(
M>C^YZ%T190@``D!(8C_92&0!`#1^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!
M`(!H>C^Y2'H_N>A>#GD(``)`#'P2F`QX$)KH7@U1"``"0`Q\$I#H7A8Q"``"
M0(>`(()(?#^YAX`@<DA\/[D/@!`<TYP?^(>`(%(,<!":(XLP`#>9`%#H70X%
M"``"0`@<`E,,<!"<BGP@$DAZ/[GH7QO-"``"0$AB/]DT?@"`3\,_@>A`P`)K
MPC_9"`,"00@>`D-OP0$`:&0`(&AY/[$T&@``Z%T.C0@``D`/@!"<"!P"6NA=
M"2T(``)`"!P"6NA="34(``)`#X`0G`^($(0T&@``Z%T.+0@``D`/@!"<"!P"
M6NA=",T(``)`"!P"6NA=$34(``)`#X`0'-.<&_A@G``P-!H``.A=#<4(``)`
M#X`0G`@<`EKH70AE"``"0`@<`EKH70AM"``"0`^`$)P/B!"$-!H``.A=#64(
M``)`#X`0G`@<`EKH70@%"``"0`@<`EKH70^M"``"0`^`$)Q+G``@TYP9%].<
M&_!DG``T-!H``.A=#.T(``)`#X`0G`@<`EKH70>-"``"0`@<`EKH70>5"``"
M0`^`$)P/B!"$-!H``.A=#(T(``)`#X`0G`@<`EKH70<M"``"0`@<`EHCBR``
M-YD/2#08``#H70=="``"0&B<`#@T&@``Z%T,'0@``D`/@!"<"!P"6NA=!KT(
M``)`"!P"6NA=!L4(``)`#X`0G`^($(0T&@``Z%T+O0@``D`/@!"<"!P"6NA=
M!ET(``)`"!P"6NA=#.4(``)`#X`0G&B<`$`T&@``Z%T+70@``D`/@!"<"!P"
M6NA=!?T(``)`"!P"6NA=!@4(``)`#X`0G`^($)P,?!*8-!H``.A="O4(``)`
M#X`0G`@<`EKH7065"``"0`@<`EKH70N]"``"0`^`$)R'@"!J-!H``.A="I4(
M``)`#X`0G`@<`EKH704U"``"0`@<`EKH70M="``"0`^`$)Q+G`#8#'P2D.@`
M``(,8!*0#'`0G`QX$)-J?`!(-!H``.A="@4(``)`#X`0G`@<`EKH702E"``"
M0`@<`EKH702M"``"0`^`$)P/B!"<:X``4#0:``#H70F="``"0`^`$)P('`):
MZ%T$/0@``D`('`):Z%T$10@``D`/@!"<#X@0G&N``%@T&@``Z%T)-0@``D`/
M@!"<"!P"6NA=`]4(``)`"!P"6NA=`]T(``)`#X`0G`^($(0T&@``Z%T(U0@`
M`D`/@!"<"!P"6NA=`W4(``)`"!P"6NA="%T(``)`#X`0G&B<`&!(8C_92&0`
M(#1^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!`(!H>3^Q-!H``.A=""4(``)`
M#X`0G`@<`EKH70+%"``"0`@<`EHT&3__Z%T(Q0@``D`T&@``Z%T'S0@``D`/
M@!"<"!P"6NA=`FT(``)`"!P"4R.+,``WG`$(#X`0G`@3`EH('`)9-!@``.A=
M!(4(``)`2&(_V31^`(!/PS^!Z$#``FO"/]D(`P)!"!X"0V_!`0!H>3^Q:&``
M(#0:``#H70;]"``"0`^`$)P('`):Z%T!G0@``D`('`):Z%T$Y0@``D`('`)3
M-!P``@Y\$@`CBR``-YH,^.A=$F4(``)`#'P2F`QX$)R'@"!*#'@0G`^`$!S3
MDQ_X-!P`8HI\("(,>!"<-YP``@^`$!S3G!_XAX`@"NA>"-$(``)`-!H``.A=
M!?T(``)`#X`0G`@<`EKH70"="``"0`@<`EHCBS``-YD!$#08``(T%P`6Z%T#
MA0@``D!H?`!(2'P`2(>`(V)(?`!(#Y@0G$N<`#!H?`!`-!P``FA\`"CH``(*
M-!H``.A=!3T(``)`#X`0G`@<`EKH71_9"``"0`@<`E-(?``H-YP__P@3`EI(
M>0!`"!P"6#07``#H701U"``"0&A\`#A(?``XAX`AHBM@(``T/`9P#X`0DTA\
M`"C7G`A""Y,*'`^`$)QH?`!P2'P`.`^`$)P/D!"3-!P(``N3`AR'@"`B2'P`
M.`^`$)P/F!"<:'P`:.@``((T&@``Z%T$#0@``D`/@!"<"!P"6NA='JD(``)`
M"!P"4TA\`#@/@!"<"!,"6@@<`EDT&```-!<`!.A=`X4(``)`:'P`:$AZ`'!(
M>0!HZ%T`O0@``D"/@"!:2'P`(#><``)H?``@2'P`*#><``)H?``H*V`@`#0\
M!F@/@!"32'P`*(N3?<4(``)`*V`@`#0\!F@/@!"<-Y,__TA\`""*?""Z-!P`
M`FA\`"CH``!R-!H``.A=`K4(``)`#X`0G`@<`EKH71U1"``"0`@<`EI(>0!`
MZ%T>\0@``D!H?``P2'P`*#><``)H?``H*V`@`#0\!F@/@!"32'P`*(N3?UT(
M``)`-!H``.A=`@T(``)`#X`0G`@<`EKH71RI"``"0`@<`EHCBS``-YD!(#08
M``(T%P`*Z%T?D0@``D!H?`!(2'P`2(>`(3(T&@``Z%T!A0@``D`/@!"<"!P"
M6NA='"$(``)`"!P"4TA\`$@/F!"<#X`0G`@3`EH('`)9(XLP`#>8`2CH71VQ
M"``"0$A\`$@/F!"<#X`0G`^0$),C@``("Y,"'(>`('(T&@``Z%T`Q0@``D`/
M@!"<"!P"6NA=&V$(``)`"!P"4TA\`$@/F!"<#X`0G`@3`EH('`)9Z%T#Y0@`
M`D`T&@``Z%T`30@``D`/@!"<"!P"6NA=&ND(``)`"!P"6B.+,``WF0$X-!@`
M`C07``KH71W1"``"0&A\`$A(?`!(AX`A:@Q@$I`CBR``-YH,P.A="XT(``)`
M#'P2D`QP$)R'@"""-!H``.A='X$(``)`#X`0G`@<`EKH71HA"``"0`@<`E-(
M?`!(#Y@0G`^`$)P($P):"!P"60QP$)CH71NY"``"0.@``*(T&@``Z%T>^0@`
M`D`/@!"<"!P"6NA=&9D(``)`"!P"4TA\`$@/F!"<#X`0E"M@(``(`0)<-YP&
M<`^`$)P/@!"<"!,"6@@4`ED('`)8Z%T%C0@``D`T&@``Z%T>40@``D`/@!"<
M"!P"6NA=&/$(``)`"!P"6NA='#D(``)`#X`2`#0:``#H71WY"``"0`^`$)P(
M'`):Z%T8F0@``D`('`):Z%T?80@``D`/@!*`(XL@`#>:#*CH70EU"``"0`@<
M`E,K8"``"`$"7#><!F`/DQ*`*V`@``@!`EPWG`9@#X`0G(^`(NHK8"``-#P&
M<`^`$)P('`):Z%\9:0@``D`('`)3*V`@``@!`EPWG`9@#Y,2@$A\`$@/F!"<
M#X`0G`^0$),T'`@`"Y,"'(>`("I(?`!(#Y@0G`^`$)P/F!"<:'P`8.@``(HT
M&@``Z%T<<0@``D`/@!"<"!P"6NA=%Q$(``)`"!P"4TA\`$@/F!"<#X`0G`@3
M`EH('`)9-!@``#07``3H71OA"``"0&A\`&`K8"``-#P&<`^`$)Q(>@!@"!P"
M6>A=&L$(``)`:'P`*"M@(``(`0)<-YP&<`^`$)P/@!"<:'P`6$A\`$@/F!"<
M#X`0G`^0$),T'`@`"Y,"'(>`("I(?`!(#Y@0G`^`$)P/F!"<:'P`4.@``(HT
M&@``Z%T;"0@``D`/@!"<"!P"6NA=%:D(``)`"!P"4TA\`$@/F!"<#X`0G`@3
M`EH('`)9-!@``#07``3H71IY"``"0&A\`%`CBS``-YH!0$AY`%A(>`!02'<`
M*.A='%D(``)`*V`@`#0\!F`/@!"<"!P"6C09`]KH713!"``"0&A\`"A(?``H
MAX`@DDAS`"@T'``B@GP@>DA\`"B'GR!J*V`@`#0\!G`/@!"<#X`0E"M@(``T
M/`9@#X`0DR.+,``WF@&@"!0"60@3`EA(=P`HZ%T;<0@``D!(8C_9-'X`@$_#
M/X'H0,`":\(_V0@#`D$('@)#;\$`@#0:``#H71D9"``"0`^`$)P('`):Z%T3
MN0@``D`('`):Z%T?&0@``D`T&@``Z%T8R0@``D`/@!"<"!P"6NA=$VD(``)`
M"!P"4R.+,``WG`)P#X`0E".+(``WG`](:]P_F6O`/Y$($P):(XLP`#>9`D`(
M%`)8(XL@`#>7#TCH71J)"``"0$AB/]DT?@"`3\,_@>A`P`)KPC_9"`,"00@>
M`D-OP0$`:'H_N6AY/[%H>#^I-'P_N31S/[$T=#^I"!P"6@@3`ED(%`)8Z%T6
M$0@``D`CBS``-YP"B`^`$)0CBS``-YP"D`^`$),CBS``-YP"D`^`$)P(%`):
M"!,"60@<`ECH0`CX"``"0#0:``#H714)"``"0`^`$!S3G!_XCX`@^NA=$>$(
M``)`"!P"4RM@(``(`0)<-YP&6`^3$H`K8"``"`$"7#><!E@/@!"<CX`@$C0:
M``+H712Y"``"0"M@(``T/`98#X`0G`@<`EKH71AI"``"0#0:``#H718Q"``"
M0`^`$)P('`):Z%T0T0@``D`('`):Z%T1V0@``D`/@!(`-!H``.A=%=D(``)`
M#X`0G`@<`EKH71!Y"``"0`@<`EKH71=A"``"0`@<`E,.8!`<TYP;^->?'#_3
MG!OX#GP2`#0:``#H7159"``"0`^`$)P('`):Z%T/^0@``D`('`):Z%T6X0@`
M`D`('`)3#F`0'-.<&_C7GQP?TYP;^`Y\$@!(?#^Y-YP`"FA\`"@T'```:'P`
M($A\`"!(?0`H#]P2@0_=$HDOP1`6,L"J%S``2!8R]@X7-`$``F!A`#`CBS``
M-YP"H"^`$!8R]@P/,``D(.@```)@8``P0',`,#0<``(+DP*<TYP;^(^`(!HC
MCP``-YH/X.A=%?D(``)`2'P_N3><``K7G`A""!P"6NA=#RD(``)`"!P"4RM@
M(``(`0)<-YP&<`^3$H`K8"``"`$"7#><!G`/@!"32'P_L0^`$)P.?!*`*V`@
M``@!`EPWG`9P#X`0G#>3``@CBS``-YP">`Y\$H`K8"``"`$"7#><!G`/@!"<
M-Y,`$"M\[_\(`0)<-YP)"`Y\$H`K8"``"`$"7#>3!F@T'``&#GP2@"M@(``(
M`0)<-YP&<`^`$),K8"``"`$"7#><!F@/@!"<UYP(0@N3"A,CBS``-YP"@`Y\
M$H`K8"``"`$"7#><!F@/@!"<-Y,``BM@(``(`0)<-YP&:`^3$H`T'``"#'P2
MD.@``+(K8"``-#P&<`^`$)0K8"``-#P&:`^`$),,<!"<"Y,*')>3``(($P)<
MUYP+W@I\!!S7G`A""Y0*%$AS/[$,<!"<UYP(0@N3"AP/@!"<#IP2@`QP$)PW
MG``"#'P2D$AS/[D,<!"<BY-_+0@``D`K8"``-#P&<`^`$)1(<S^Y*V`@`#0\
M!F@/@!"<"Y,*')>3``(($P)<UYP+W@I\!!S7G`A""Y0*'`^`$H`K8"``-#P&
M6`^`$)5(<S^Y*V`@`#0\!F@/@!"<"Y,*'#>3/_\K8"``-#P&<`^`$)0CBS``
M-YP"L`^`$)QKP#^9"!4"6@@<`ED($P)8"!0"5^A=#!$(``)`#'P2F`QX$)R/
M@"`R*V`@`#0\!E@/@!"<"!P"6NA=$>D(``)`#'P2F"M@(``T/`98#X`0G`@<
M`EKH70[Q"``"0".+(``WF@T8Z%T;*0@``D"/@""R*V`@`#0\!F`/@!"<CX`@
M0B.+(``WF@RHZ%T:X0@``D`('`)3*V`@``@!`EPWG`9@#Y,2@"M@(``T/`9@
M#X`0G(>`("HK8"``-#P&8`^`$)P('`):Z%\>F0@``D`K8"``-#P&6`^`$)P(
M'`):Z%T-`0@``D#H71`Q"``"0`QX$)Q(8C_9-'X`@$_#/X'H0,`":\(_V2M@
M``!(/`7HAX`@"#07```/@!"72\(_V>@="N$(``)`"``"0.A`P`)KPC_9;\D!
M``@:`DEKR#\)"!D"2&O'/Q$(&`)':\8_&6O%/R%KQ#\I"!,"1&O3/\'H70=1
M:\,_,0@$`E,K8```2#4%\"M@``!()@7X"-4$%=*E'Z*$H"!0-`,```S#()8(
M$P)$-&,``@@)`EH("`)9"`<"6.O@`-@('P)"B&6_M0@$`E-+PC[92\@_"4O'
M/Q%+QC\92\4_(4O$/RE+PS\QZ$#``$_)/P%KPC_9"!D"6$O"/]D(&@)9-!H`
M!N@=#.D(``)`"``"0&O"/]D(&0)82\(_V0@:`EDT&@`&Z!T'R0@``D`(``)`
MQ];`$M;`'!X.R!"3#L`0ENK`P`!KPC_1:\(_V6_$`(!KPS^)AU\@$&O3/\$T
M'!_^@UR`(@@:`EQ+PC]92\,_B>A`P`!/Q#^!Q]K?S0@:`D,K8```2#T%X-1@
M'!X,8!":-U0`((J=/YT(&@)<*V```$@W!=`.X!"<AX`@."+'#X$/J!":#N`0
ME@QH$)GK_Q[="!\"0N@?'S4,8!":#I$0E$J?`$`*WP(<(J`-`8.5("@VF`!`
M#ID0GS:8/_D*WP(<BY4^W30:/__3]1N6T_P;O]><"4K3]AGPT_0;_];6"7O6
ME`H0"K0"5`N4`E0*U`)4TIP9\(>`(!#6M`A"UI\>,=:T"$(*N`H4*V```$@\
M!=@VE``0#Y02@`^Y$)4/E1*(UY\<'N@?'JT._!*`*W___VO"/]EOQ0$`:\0_
M"6O#/Q$T(PX`#'D0A>A?'94(!0):-!H__^A?'7T('`)$@)P@6#1C/_D(!0)6
MZ_\=)0@?`D),93_YZ%\=/0@%`EHT&C__Z%\=)0@<`D2(G#^U"`4"5DO"/ME+
MQ#\)2\,_$>A`P`!/Q3\!:\(_V3?>`(!+PC]9Z$#``#?>/X'H0,`":\(_V6_$
M`(!KTS_!"!,"1.A=#*$(``)`2\(_60@$`E/H0,``3\0_@0`!YY(``>;J``'E
M*@`!YJ(``@`!`````'!E<FQX<VDN8P```$1Y;F%,;V%D97(Z.F)O;W1?1'EN
M84QO861E<@```>9"+W!R;V,O<V5L9B]E>&4``"\````Z````+W!R;V,O)6DO
M)7,`97AE`%!!4E]414U0`````%!!4E]04D]'3D%-10`````N````)7,E<R5S
M``!005)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%2
M7T1%0E5'````4$%27T-!0TA%````4$%27T%21T,`````4$%27T%21U9?,```
M4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@```%!!4E]4
M35!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`````%!!
M4E]#3$5!3CT``#$```!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@
M(`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`````
M4$%42`````!$64Q$7TQ)0E)!4EE?4$%42````````````7=@``%W<``!=W@`
M`7>(``%WD``!=Z1435!$25(``%1%35!$25(`5$5-4`````!435````%V_``!
M=\```7?(``%WT``!=]@``7>D0SI<5$5-4``O=&UP```````!=_0``7?\``%V
M<``!=Z154T52`````%5315).04U%`````'!A<BT`````4UE35$5-```E<R5S
M)7,E<P`````E<V-A8VAE+25S)7,`````)3`R>``````E<W1E;7`M)74E<P`E
M<W1E;7`M)74M)74E<P``+BX``"5S+R5S``````'E`D%21U8`````&````'!E
M<FP`````,````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("T@86)O<G1I
M;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('1E;7!O<F%R
M>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*
M````26YT97)N86QS.CI005(Z.D)/3U0```````'EFBUE```M+0````'F4@`!
MY4H`````0<____^``````>4*`````'!A<BYP;```(R$O=7-R+V)I;B]P97)L
M"@IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*
M("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`H*<&%C
M:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R:7!T(&UU<W0@;F]T('5S
M92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@+2TM"B,@=7-E('-T<FEC
M=#L*"B-L:6YE(#$U.0H*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP
M9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*("`@(')E<75I
M<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL93HZ0F%S96YA;64["B`@
M("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D=&]P9&ER(#T@1FEL93HZ
M0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*("`@(&]U=',H<7%[4F5M
M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*("`@($9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP.PH@("`@(R!$;VXG="!R
M96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S97,@82!R86-E('=I=&@@
M;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI;F<@=&\@<W1A<G0N"@H@
M("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["B`@
M("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U;FQI;FMI;F<@=&AE('1E
M;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@("`@(R!T>7!I8V%L;'D@
M:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A;&QO=R!U;FQI;FMI;F<@
M<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD(&5X96-U=&%B;&5S('1H
M870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B86-K9W)O=6YD"B`@("`@
M("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE<R!A<F4@;F\@;&]N9V5R
M(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@("`@(R!$;VXG="!D;R!A
M;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R('!A<F5N="!P<F]C97-S
M('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C;&5A;FEN9R!T:&EN9W,@
M=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*("`@("`@
M("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*("`@("`@("`@("`@1$E2
M(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`H@("`@("`@
M("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@("`@("!53DQ)3DL@/3X@
M,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D=&UP("(C(2]B:6XO<V@*
M>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*("`@<FT@+7)F("<D<&%R
M7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@H@("`@
M("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X/6!E>'!R(%PD>"`K(#%@
M"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["B`@("`@("`@
M("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["B`@("`@("`@;7D@)&-M
M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["B`@
M("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T96TH)&-M9"D["B`@("`@
M("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F
M;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@)'1M<"T^9FEL96YA;64I
M.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["@H@("`@979A
M;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI<W1S("1%3E9[4$%27T%2
M1U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2!["B`@("!`05)'5B`](&UA
M<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D14Y6>U!!4E]!4D=#?2`M
M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PH@("`@
M9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE=&4@)$5.5GLD7WT@:68@
M+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I970@/2`A)$5.5GM005)?
M1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN=F]K960@9G)O;2!0051(
M"FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@("`]/B`H)%Y/(#U^("]>
M35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"B`@
M("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D[
M"@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@97AT<F%C=&EN9R!B=6YD
M;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI[
M"B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*"B`@("`C($-H
M96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A=&$@<V5C=&EO;B![>WL*
M("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PH@("`@8FEN
M;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S965K(%]&2"P@+3@L(#([
M"B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA<W0@=6YL97-S("1B=68@
M97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(+"`M,3(L(#(["B`@("!R
M96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(+"`M,3(@+2!U;G!A8VLH
M(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH*("`@("1D
M871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@(R!]?7T*"B`@("`C($5X
M=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y('M[>PH@("`@;7D@)7)E
M<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PH@("`@
M("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F
M+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@;7D@)&9U;&QN86UE(#T@
M)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA
M;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\
M7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*("`@("`@("!M>2`H
M)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN
M+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@(')E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E
M;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@
M("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@
M('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@("`@(&-L;W-E("1O=70[
M"B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D9FEL96YA;64["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@("`@("`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["B`@("`@("`@
M?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_<VAL:6(O?"!A
M;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*("`@("`@("`@("`@(R!S
M:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*("`@("`@("`@("`@;7D@
M)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B87-E;F%M921E>'0B.PH@
M("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*("`@("`@
M("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$[
M"B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@('!R:6YT
M("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@)&]U=#L*("`@("`@("!]
M"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R97%U:7)E7VQI<W1[)&9U
M;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@("`@8G5F(#T^("1B=68L
M"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*("`@("`@("`@("`@("`@
M(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@("!].PH@("`@("`@('T*
M("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('T*("`@(",@?7U]"@H@
M("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@(&UY("@D<V5L9BP@)&UO
M9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R
M("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA;64@/2!D96QE=&4@)')E
M<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@("`@("`@("`@(&UY("1K
M97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@
M>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@+UQ1)&UO9'5L95Q%)"\[
M"B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA<W0["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@
M9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E='5R;CL*"B`@("`@("`@
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE;F%M92\D;6]D=6QE(CL*
M"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z
M.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@)&9H(#T@24\Z.D9I;&4M
M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D
M9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I;&5N86UE+3Y[8G5F?3L*
M("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@("`@("`@("`@("!R971U
M<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE
M+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@
M("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U
M="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("`@("`@8VQO<V4@)&]U
M=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O<&5N(&UY("1F:"P@)SPG
M+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*
M("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@("!]"@H@("`@("`@(&1I
M92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A
M7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@;&]A9"!A;&P@8G5N9&QE
M9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@<VAA<F5D(&]B:F5C="!P
M<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R.PH@("`@<F5Q=6ER92!0
M05(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN
M86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R>2!G971T:6YG(&AE;'!E
M<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U:7)E($E/.CI&:6QE.PH*
M("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I;@H@("`@=VAI;&4@*&UY
M("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*
M("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D
M7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S<R`H)$E.0WLD9FEL96YA
M;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PH@("`@("`@("`@("`C
M(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE8W5T86)L92!F:6QE<PH@
M("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*("`@
M("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@(R!3:VEP($%C
M=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F:6QE.@H@("`@("`@("`@
M("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C
M=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("`@
M("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*("`@('T*"B`@
M("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.PI]"B,@?7U]"@HC
M($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P87)?87)G<SL*;7D@*"1O
M=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA;64I.PH*)'%U:65T(#T@
M,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PH*(R!$;VXG="!S=V%L;&]W(&%R
M9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A
M<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@
M<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A
M;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@
M<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("!M
M>2!`861D7W1O7VEN8SL*("`@('=H:6QE("A`05)'5BD@>PH@("`@("`@("1!
M4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0[
M"@H@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@<'5S:"!`
M861D7W1O7VEN8RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E
M<2`G32<I('L*("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@("!]
M"B`@("`@("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("!U;G-H
M:69T($!P87)?87)G<RP@)#(["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D
M,2!E<2`G3R<I('L*("`@("`@("`@("`@)&]U="`]("0R.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@("`@("1B=6YD
M;&4@/2`G<VET92<["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G
M0B<I('L*("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("1Q=6EE
M="`](#$["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*
M("`@("`@("`@("`@;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8
M.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*("`@("`@("!]"B`@("`@("`@96QS
M:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R
M.PH@("`@("`@('T*"B`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("!I
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@("`@("`@9&5L
M971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@("`@(&EN:71?:6YC*"D[
M"B`@("`@("`@("`@(')E<75I<F4@4$%2.CI$:7-T.PH@("`@("`@("`@("`F
M>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@
M("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@("`@
M("`@("`@97AI=#L*("`@("`@("!]"B`@("!]"@H@("`@=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0H*(R!86%@@+2T@861D("TM<&%R+61E8G5G('-U
M<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L:6YG('M[
M>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N
M<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@
M<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z.EII
M<#L*("`@('T*"@H@("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY
M("1Z:7`["@H*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N
M(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G
M.B`D(2(["B`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F
M:"P@)TE/.CI&:6QE)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M
M/FYE=SL*("`@("`@("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L
M("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@
M(&]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@
M;7D@)65N=B`](&1O('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@
M/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@
M<R]>7%,N*B\O;7,["B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI
M.B`H+BLI)"]M9SL*("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U
M="!A;F0@;W5T<'5T(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@
M("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD[
M"B`@("`@("`@9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@
M/%!!4CX@97$@(E!+7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H
M)&]U="D@.PH@("`@"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@
M("`@("1O=70L"B`@("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&
M:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@
M("`P-S<W+`H@("`@*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@
M("`@)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N
M9&5F.PH@("`@<V5E:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A
M;&%R(#Q?1D@^.PH@("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L
M;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP+3YN97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O
M<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D
M=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L
M("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D
M<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L
M;V%D97(@/7X@<WLD;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@
M)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@
M("`@("`@?65G.PH@("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@
M("0O(#T@=6YD968["B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M
M;V1U;&5S('M[>PH@("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E
M(%!!4CHZ2&5A=GD["B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO
M861E<B@I.PH@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@<F5Q=6ER95]M
M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@("`@("`@
M("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@9W)E<"![
M"B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"!["B`@("`@
M("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@("`@*"1?
M(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@("`@("`@
M("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["B`@("`@
M("`@?2!`24Y#.PH*("`@("`@("!I9B`H)$-O;F9I9WM?9&5L:6U](&5Q("=<
M7"<I('L@<WM<7'U[+WUG(&9O<B!`:6YC('T*"B`@("`@("`@;7D@)69I;&5S
M.PH@("`@("`@("]>7SPH+BLI)"\@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*
M"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL
M92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@
M("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D
M,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@
M(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@
M("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@
M("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I
M9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X[
M"B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@
M("`@("`@("`@("`C($1O(&YO="!L970@6%-,;V%D97(@<&EC:R!U<"!A=71O
M+RH@9G)O;2!E;G9I<F]N;65N=`H@("`@("`@("`@("`@("`@)&-O;G1E;G0@
M/7X@<R]G;W1O("MR971R>2`K=6YL97-S("LN*B]G;W1O(')E=')Y.R\*("`@
M("`@("`@("`@("`@("`@("!I9B!L8R@D;F%M92D@97$@;&,H(EA33&]A9&5R
M+G!M(BD["B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&]U=',H<7$H5W)I
M='1E;B!A<R`B)&YA;64B*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H(D9)
M3$4B*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H
M*"1N86UE*2`K(#DI*3L*("`@("`@("`@("`@)&9H+3YP<FEN="AS<')I;G1F
M*`H@("`@("`@("`@("`@("`@(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"B`@("`@("`@("`@("DI.PH@
M("`@("`@("`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H)&-O;G1E;G0I.PH@("`@
M("`@('T*("`@('T*("`@(",@?7U]"@H@("`@(R!.;W<@=W)I=&4@;W5T('1H
M92!005(@86YD(&UA9VEC('-T<FEN9W,@>WM["B`@("`D>FEP+3YW<FET951O
M1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["@H@("`@)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PH@("`@:68@*"$D8V%C:&5?;F%M
M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2!["B`@("`@("`@
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@
M('Q\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^
M;F5W('T["@H@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G(&EN($1I9V5S
M=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("!M>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@
M("!I9B`H)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@
M97$@)S4N,SDG*2!["B`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&]U="P@
M(F(B*2!I9B`H)&-T>"D["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)&]U="(I*2![
M"B`@("`@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@
M("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("`D8V%C:&5?
M;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["B`@("!]
M"B`@("`D8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H
M95]N86UE*3L*("`@("1C86-H95]N86UE("X](")#04-(12(["B`@("`D9F@M
M/G!R:6YT*"1C86-H95]N86UE*3L*("`@("1F:"T^<')I;G0H<&%C:R@G3B<L
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PH@("`@)&9H+3YP<FEN
M="@B7&Y005(N<&U<;B(I.PH@("`@)&9H+3YC;&]S93L*("`@(&-H;6]D(#`W
M-34L("1O=70["B`@("`C('U]?0H*("`@(&5X:70["GT*(R!]?7T*"B,@4')E
M<&%R92`D<')O9VYA;64@:6YT;R!005(@9FEL92!C86-H92![>WL*>PH@("`@
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PH*("`@(%]F:7A?<')O
M9VYA;64H*3L*"B`@("`C($YO=R!L;V%D('1H92!005(@9FEL92!A;F0@<'5T
M(&ET(&EN=&\@4$%2.CI,:6)#86-H92![>WL*("`@(')E<75I<F4@4$%2.PH@
M("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*"B`@("!["B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*("`@("`@("!R97%U:7)E($9I;&4Z.D9I;F0["B`@
M("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"B`@("!M>2`D>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^
M;F5W.PH@("`@)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M("(D(3H@)$`B.PH@("`@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PH*("`@('!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`["B`@("`D
M4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*"B`@("`D<75I970@
M/2`A)$5.5GM005)?1$5"54=].PH@("`@;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["@H@("`@:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"B`@("`@("`@9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I
M('L*("`@("`@("`@("`@;F5X="!I9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*
M("`@("`@("`@("`@;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^9FEL94YA
M;64["B`@("`@("`@("`@(&YE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PH@("`@("`@("`@("`@("`@7@H@("`@("`@("`@("`@("`@+S]S:&QI8B\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I
M/PH@("`@("`@("`@("`@("`@*#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PH@("`@("`@("`@("`@("`@*%M>+UTK*0H@("`@("`@("`@("`@("`@
M)`H@("`@("`@("`@("!]>#L*("`@("`@("`@("`@;7D@)&5X=')A8W1?;F%M
M92`]("0Q.PH@("`@("`@("`@("!M>2`D9&5S=%]N86UE(#T@1FEL93HZ4W!E
M8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D["B`@
M("`@("`@("`@(&EF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E
M<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["B`@("`@("`@("`@("`@("!O=71S
M*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("!](&5L<V4@
M>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PH@("`@("`@("`@("`@("`@)&UE
M;6)E<BT^97AT<F%C=%1O1FEL94YA;65D*"1D97-T7VYA;64I.PH@("`@("`@
M("`@("`@("`@8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H
M<'5X(CL*("`@("`@("`@("`@?0H@("`@("`@('T*("`@('T*("`@(",@?7U]
M"GT*(R!]?7T*"B,@268@=&AE<F4G<R!N;R!M86EN+G!L('1O(')U;BP@<VAO
M=R!U<V%G92![>WL*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]
M*2!["B`@("!D:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P(%L@
M+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP87(@
M72!;('!R;V=R86TN<&P@70H@("`@("`@)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N
M86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*(R!]?7T*"G-U8B!#<F5A=&50
M871H('L*("`@(&UY("@D;F%M92D@/2!`7SL*("`@(`H@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(&UY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*("`@(`H@("`@<F5Q=6ER92!&:6QE.CI0871H.PH@("`@"B`@("!&:6QE
M.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP
M871H(&1I97,@=VET:"!E<G)O<@I]"@IS=6(@<F5Q=6ER95]M;V1U;&5S('L*
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["@H@("`@<F5Q=6ER92!L:6(["B`@("!R97%U:7)E($1Y
M;F%,;V%D97(["B`@("!R97%U:7)E(&EN=&5G97(["B`@("!R97%U:7)E('-T
M<FEC=#L*("`@(')E<75I<F4@=V%R;FEN9W,["B`@("!R97%U:7)E('9A<G,[
M"B`@("!R97%U:7)E($-A<G`["B`@("!R97%U:7)E($-A<G`Z.DAE879Y.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R
M=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M
M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D
M97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L
M93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S
M.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E
M(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2
M.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@
M("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V86P@>R!R97%U:7)E(%=I
M;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*("`@
M(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PI]"@HC
M(%1H92!#('9E<G-I;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O
M;6MT;7!D:7(N8PIS=6(@7W-E=%]P87)?=&5M<"!["B`@("!I9B`H)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@
M("`@("1P87)?=&5M<"`]("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@
M("!F;W)E86-H(&UY("1P871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@
M("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE
M>'0@=6YL97-S("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["B`@
M("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P=W5I9#L*("`@("`@
M("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@("`@("!E=F%L('LH
M)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["@H@("`@
M("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B`@("`@
M("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PH@("`@("`@
M('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*("`@("`@("`@
M("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM54T523D%-17T@?'P@
M)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]"B`@("`@("`@)'5S
M97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D<W1M<&1I<B`]("(D
M<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B.PH@("`@("`@(&UK
M9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A)$5.5GM005)?0TQ%
M04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PH@
M("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*("`@
M("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@("`@("`@<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D9F@L("TU."P@,CL*
M("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F+"`T,3L*("`@("`@
M("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@("`@("`@("`@("1S
M=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@)&)U9CL*("`@
M("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@
M(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"B`@
M("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-
M1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@("`@("`@("`C(%=O
M<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U+C,X(&%N9"`U+C,Y
M"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I
M9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@("`@("`@("`@(&EF
M("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G
M-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@("`@("!I9B`H
M)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*("`@("`@
M("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@
M("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@("`@("`@("`@("`@
M("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]
M("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X
M9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@
M("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@("`@("1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@("`@("!]"@H@("`@
M("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@("`@("`@;6MD:7(@
M)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@('T*"B`@("`D<&%R
M7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-
M4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*("`@(&UY("@D97AT
M+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N86UE*3L*"B`@("`D
M9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*"B`@("!I9B`H)$5.
M5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F:6QE;F%M92!I9B`M
M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE
M.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N("AU;F1E9BP@)&9I
M;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*"B`@("!O<&5N("1F
M:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D9F@I
M.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*<W5B(%]S971?<')O
M9VYA;64@>PH@("`@:68@*"1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.5GM0
M05)?4%)/1TY!345](#U^("\H+BLI+RD@>PH@("`@("`@("1P<F]G;F%M92`]
M("0Q.PH@("`@?0H*("`@("1P<F]G;F%M92!\?#T@)#`["@H@("`@:68@*"1%
M3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%
M35!]*2`^/2`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G
M;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I
M.PH@("`@?0H*("`@(&EF("@A)$5.5GM005)?4%)/1TY!345](&]R(&EN9&5X
M*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^/2`P*2!["B`@("`@("`@
M:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@>PH@("`@("`@("`@
M("!R971U<FX@:68@+7,@)&9H.PH@("`@("`@('T*("`@("`@("!I9B`H+7,@
M(B1P<F]G;F%M921#;VYF:6=[7V5X97TB*2!["B`@("`@("`@("`@("1P<F]G
M;F%M92`N/2`D0V]N9FEG>U]E>&5].PH@("`@("`@("`@("!R971U<FX["B`@
M("`@("`@?0H@("`@?0H*("`@(&9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)$-O;F9I9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*("`@("`@("!N
M97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6
M>U!!4E]414U0?3L*("`@("`@("`D9&ER(#U^(',O7%$D0V]N9FEG>U]D96QI
M;7U<120O+SL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T*0H@("`@("`@
M("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*("`@("`@("`@("`@:68@+7,@
M(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0I]"@IS=6(@
M7V9I>%]P<F]G;F%M92!["B`@("`D,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PH@("`@:68@*&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I
M9WM?9&5L:6U]*2`\(#`I('L*("`@("`@("`D<')O9VYA;64@/2`B+B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"@H@("`@(R!86%@@+2!H86-K
M('1O(&UA:V4@4%=$('=O<FL*("`@(&UY("1P=V0@/2`H9&5F:6YE9"`F0W=D
M.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0H@("`@("`@("`@("`@("`@.B`H
M*&1E9FEN960@)E=I;C,R.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@
M8'!W9&`I.PH@("`@8VAO;7`H)'!W9"D["B`@("`D<')O9VYA;64@/7X@<R]>
M*#\]7"Y<+C]<421#;VYF:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L
M:6U]+SL*"B`@("`D14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*
M"G-U8B!?<&%R7VEN:71?96YV('L*("`@(&EF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*("`@("`@("!R971U<FX["B`@("!](&5L<V4@
M>PH@("`@("`@("1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["B`@("!]"@H@
M("`@9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!2
M3T=.04U%($%21T,@05)'5E\P("D@*2!["B`@("`@("`@9&5L971E("1%3E9[
M)U!!4E\G+B1??3L*("`@('T*("`@(&9O<B`H<7<O(%1-4$1)4B!414U0($-,
M14%.($1%0E5'("\I('L*("`@("`@("`D14Y6>R=005)?)RXD7WT@/2`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,
M7R<N)%]].PH@("`@?0H*("`@(&UY("1P87)?8VQE86X@/2`B7U]%3E9?4$%2
M7T-,14%.7U\@("`@("`@("`@("`@("`B.PH*("`@(&EF("@D14Y6>U!!4E]4
M14U0?2D@>PH@("`@("`@(&1E;&5T92`D14Y6>U!!4E]#3$5!3GT["B`@("!]
M"B`@("!E;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2![
M"B`@("`@("`@;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@
M;&5N9W1H*")#3$5!3B(I*3L*("`@("`@("`D14Y6>U!!4E]#3$5!3GT@/2`D
M,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PH@("`@?0I]"@IS
M=6(@;W5T<R!["B`@("!R971U<FX@:68@)'%U:65T.PH@("`@:68@*"1L;V=F
M:"D@>PH@("`@("`@('!R:6YT("1L;V=F:"`B0%]<;B(["B`@("!]"B`@("!E
M;'-E('L*("`@("`@("!P<FEN="`B0%]<;B(["B`@("!]"GT*"G-U8B!I;FET
M7VEN8R!["B`@("!R97%U:7)E($-O;F9I9SL*("`@('!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"B`@("`@
M("`@87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*("`@("`@("!V96YD;W)A<F-H97AP('9E;F1O<FQI8F5X<`H@("`@*3L*
M?0H*(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C"B,@5&AE(&UA:6X@<&%C
M:V%G92!F;W(@<V-R:7!T(&5X96-U=&EO;@H*<&%C:V%G92!M86EN.PH*<F5Q
M=6ER92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M
M/FEM<&]R="A`<&%R7V%R9W,I.PH*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN*0H@("`@=6YL97-S("UE("1P<F]G;F%M93L*"F1O("1P<F]G
M;F%M93L*0T]213HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("1`(&EF("1`.PH*?3L*"B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0H*0T]213HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]4
M2U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T52
M4D]2.PH*,3L*"B-L:6YE(#DY,PH*7U]%3D1?7PH````````6_```%S`(`0`(
M````"```'"@``!RX"`0`"`````@``!R\```<S`@```@````(```<T```'0@(
M```(````"```'0P``!T<"```"`````@``!T@```=D`@!`!@````(```=E```
M'J`(`0`8```""```'J0``!_L"`$`&````!```!_P```@)`@!`!@````(```@
M*```(_0(`@`8````$```(_@``"2$"`$`&`````@``"2(```EO`@!`!@```00
M```EP```)>0(`0`8````"```)>@``"C<"`$`&````A```"C@```I8`@!`!``
M```(```I9```*V`(`0`8````"```*V0``"U8"`$`&````!```"U<```M]`@!
M`!@````(```M^```3PP(`0`0````.```3Q```$^0"`$`$`````@``$^4``!1
M4`@!`!@````(``!15```4YP(`0`8````"```4Z```%5("`$`&````!```%5,
M``!5H`@!`!@````(``!5I```5J`(`0`8````"```5J0``%@H"`(`&````!``
M`%@L``!@;`@#`!@``!`P``!@<```8@0(`@`8````&```8@@``&*8"`$`&```
M``@``&*<``!ET`@"`!@````0``!EU```9F`(`0`8````"```9F0``&U8"`$`
M&````!```&U<``!M_`@!`!@````(``!N````<NP(`0`8````$```<O```',4
M"```"````````',8``!S&`@```````````!S'```<\`(!P`(````$```<\0`
M`'/@"```"````````'/D``!T``@```@```````!T!```=!A(````````````
M=!P``'4L"`(`"`````@``'4P``!UI`@#``@````0``!UJ```=;@(```(````
M"```=;P``'6\"````````````'7```!UY`@!``@````(`1L#.P```!`````!
M__^@A````"@````0``````%Z4@`!!`(!&PP>`````!@````8__^@5````10`
M2!-P1(,!A``1`GL`````_____P````#_____```````````````!`````0``
M``$```+(`````0```M,````!```"W0````$```,L`````0``!#\````,``$6
M_`````T``77`````!``!`40````%``$+S`````8``02<````"@``!=`````+
M````$`````,``>3D````%0`````````"```#Y````!0````'````%P`!$P@`
M```'``$2Y`````@````D````"0````QO___^``$2A&____\````";___\``!
M$9P`````````````````````````````````````````````````````````
M```````````````````!=CP``79`_____P`!>6```%=<``%BG``!Y.0``6U<
M``'DY```````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````````````````.@!"6ZL#`
M``Z($)7JGQ_=UH`<'@#`_^[>K;[O``'C]````````?@@``'X)````````>3H
M``'CX``!X^``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``
M1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U
M;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS
M+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T
M*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``
M1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U
M;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS
M+35U8G5N='4T*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T
M*2`T+C,N,P``1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P``
M1T-#.B`H56)U;G1U(#0N,RXS+35U8G5N='4T*2`T+C,N,P`````&````````
M``$P,2XP,0````````8``````````3`Q+C`Q````````!@`````````!,#$N
M,#$````````&``````````$P,2XP,0````````8``````````3`Q+C`Q````
M````!@`````````!,#$N,#$`````+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M04))+71A9P`N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG
M;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`
M+F9I;FD`+G)O9&%T80`N4$%225-#+G5N=VEN9``N96A?9G)A;65?:&1R`"YE
M:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YJ8W(`+F1Y;F%M:6,`+F1A=&$`+F=O
M=``N8G-S`"YC;VUM96YT`"YN;W1E````````````````````````````````
M````````````````````````````"P````$````"``$!%````10````-````
M```````````!`````````!,````'`````@`!`20```$D````(```````````
M````!``````````A````!0````(``0%$```!1````U@````$``````````0`
M```$````)P````L````"``$$G```!)P```<P````!0````$````$````$```
M`"\````#`````@`!"\P```O,```%T````````````````0`````````W;___
M_P````(``1&<```1G````.8````$``````````(````"````1&____X````"
M``$2A```$H0```!@````!0````(````$`````````%,````$`````@`!$N0`
M`!+D````)`````0`````````!`````P```!=````!`````(``1,(```3"```
M`^0````$````%@````0````,````9P````$````&``$6[```%NP```!(````
M```````````$`````````&T````!````!@`!%S0``!<T``!>C```````````
M````!`````````!S`````0````8``77```!UP````"@```````````````0`
M````````>0````$````"``%UZ```=>@``%K@```````````````(````````
M`($````!`````@`!T,@``-#(```"T``````````+````!`````0```"0````
M`0````(``=.8``#3F````!0```````````````0`````````G@````$````"
M``'3K```TZP````T```````````````$`````````*@````!`````P`!X^``
M`-/@````"```````````````!`````````"O`````0````,``>/H``#3Z```
M``@```````````````0`````````M@````$````#``'C\```T_`````$````
M```````````$`````````+L````&`````P`!X_0``-/T````\`````4`````
M````!`````@```#$`````0````,``>3D``#4Y````!P```````````````0`
M````````8@````$````'``'E````U0````+$```````````````$````"```
M`,H````!`````P`!Y\0``-?$````(```````````````!`````0```#/````
M"`````,``>?H``#7Y```$$0```````````````@`````````U`````$`````
M````````U^0```&P```````````````!`````````-T````'````````````
M`-F4````>````````````````0`````````!`````P````````````#:#```
2`.,```````````````$`````
